Class: Google::Apis::BigtableadminV2::Backup

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

A backup of a Cloud Bigtable table.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Backup

Returns a new instance of Backup.



390
391
392
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 390

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_typeString

Indicates the backup type of the backup. Corresponds to the JSON property backupType

Returns:

  • (String)


316
317
318
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 316

def backup_type
  @backup_type
end

#encryption_infoGoogle::Apis::BigtableadminV2::EncryptionInfo

Encryption information for a given resource. If this resource is protected with customer managed encryption, the in-use Cloud Key Management Service ( Cloud KMS) key version is specified along with its status. Corresponds to the JSON property encryptionInfo



323
324
325
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 323

def encryption_info
  @encryption_info
end

#end_timeString

Output only. end_time is the time that the backup was finished. The row data in the backup will be no newer than this timestamp. Corresponds to the JSON property endTime

Returns:

  • (String)


329
330
331
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 329

def end_time
  @end_time
end

#expire_timeString

Required. The expiration time of the backup. When creating a backup or updating its expire_time, the value must be greater than the backup creation time by: - At least 6 hours - At most 90 days Once the expire_time has passed, Cloud Bigtable will delete the backup. Corresponds to the JSON property expireTime

Returns:

  • (String)


337
338
339
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 337

def expire_time
  @expire_time
end

#hot_to_standard_timeString

The time at which the hot backup will be converted to a standard backup. Once the hot_to_standard_time has passed, Cloud Bigtable will convert the hot backup to a standard backup. This value must be greater than the backup creation time by: - At least 24 hours This field only applies for hot backups. When creating or updating a standard backup, attempting to set this field will fail the request. Corresponds to the JSON property hotToStandardTime

Returns:

  • (String)


347
348
349
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 347

def hot_to_standard_time
  @hot_to_standard_time
end

#nameString

A globally unique identifier for the backup which cannot be changed. Values are of the form projects/project/instances/instance/clusters/cluster/ backups/_a-zA-Z0-9* The final segment of the name must be between 1 and 50 characters in length. The backup is stored in the cluster identified by the prefix of the backup name of the form projects/project/instances/instance/ clusters/cluster`. Corresponds to the JSON propertyname`

Returns:

  • (String)


357
358
359
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 357

def name
  @name
end

#size_bytesFixnum

Output only. Size of the backup in bytes. Corresponds to the JSON property sizeBytes

Returns:

  • (Fixnum)


362
363
364
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 362

def size_bytes
  @size_bytes
end

#source_backupString

Output only. Name of the backup from which this backup was copied. If a backup is not created by copying a backup, this field will be empty. Values are of the form: projects//instances//clusters//backups/ Corresponds to the JSON property sourceBackup

Returns:

  • (String)


369
370
371
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 369

def source_backup
  @source_backup
end

#source_tableString

Required. Immutable. Name of the table from which this backup was created. This needs to be in the same instance as the backup. Values are of the form projects/project/instances/instance/tables/source_table`. Corresponds to the JSON propertysourceTable`

Returns:

  • (String)


376
377
378
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 376

def source_table
  @source_table
end

#start_timeString

Output only. start_time is the time that the backup was started (i.e. approximately the time the CreateBackup request is received). The row data in this backup will be no older than this timestamp. Corresponds to the JSON property startTime

Returns:

  • (String)


383
384
385
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 383

def start_time
  @start_time
end

#stateString

Output only. The current state of the backup. Corresponds to the JSON property state

Returns:

  • (String)


388
389
390
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 388

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



395
396
397
398
399
400
401
402
403
404
405
406
407
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 395

def update!(**args)
  @backup_type = args[:backup_type] if args.key?(:backup_type)
  @encryption_info = args[:encryption_info] if args.key?(:encryption_info)
  @end_time = args[:end_time] if args.key?(:end_time)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @hot_to_standard_time = args[:hot_to_standard_time] if args.key?(:hot_to_standard_time)
  @name = args[:name] if args.key?(:name)
  @size_bytes = args[:size_bytes] if args.key?(:size_bytes)
  @source_backup = args[:source_backup] if args.key?(:source_backup)
  @source_table = args[:source_table] if args.key?(:source_table)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
end