Class: Google::Apis::BigtableadminV2::BackupInfo
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::BackupInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
Information about a backup.
Instance Attribute Summary collapse
-
#backup ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#source_backup ⇒ String
Output only.
-
#source_table ⇒ String
Output only.
-
#start_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackupInfo
constructor
A new instance of BackupInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackupInfo
Returns a new instance of BackupInfo.
443 444 445 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 443 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup ⇒ String
Output only. Name of the backup.
Corresponds to the JSON property backup
417 418 419 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 417 def backup @backup end |
#end_time ⇒ String
Output only. This time that the backup was finished. Row data in the backup
will be no newer than this timestamp.
Corresponds to the JSON property endTime
423 424 425 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 423 def end_time @end_time end |
#source_backup ⇒ String
Output only. Name of the backup from which this backup was copied. If a backup
is not created by copying a backup, this field will be empty. Values are of
the form: projects//instances//clusters//backups/
Corresponds to the JSON property sourceBackup
430 431 432 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 430 def source_backup @source_backup end |
#source_table ⇒ String
Output only. Name of the table the backup was created from.
Corresponds to the JSON property sourceTable
435 436 437 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 435 def source_table @source_table end |
#start_time ⇒ String
Output only. The time that the backup was started. Row data in the backup will
be no older than this timestamp.
Corresponds to the JSON property startTime
441 442 443 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 441 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
448 449 450 451 452 453 454 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 448 def update!(**args) @backup = args[:backup] if args.key?(:backup) @end_time = args[:end_time] if args.key?(:end_time) @source_backup = args[:source_backup] if args.key?(:source_backup) @source_table = args[:source_table] if args.key?(:source_table) @start_time = args[:start_time] if args.key?(:start_time) end |