Class: Google::Apis::BigtableadminV2::ChangeStreamConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

Change stream configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ChangeStreamConfig

Returns a new instance of ChangeStreamConfig.



570
571
572
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 570

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#retention_periodString

How long the change stream should be retained. Change stream data older than the retention period will not be returned when reading the change stream from the table. Values must be at least 1 day and at most 7 days, and will be truncated to microsecond granularity. Corresponds to the JSON property retentionPeriod

Returns:

  • (String)


568
569
570
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 568

def retention_period
  @retention_period
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



575
576
577
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 575

def update!(**args)
  @retention_period = args[:retention_period] if args.key?(:retention_period)
end