Class: Google::Apis::BigtableadminV2::CheckConsistencyRequest
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::CheckConsistencyRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
Request message for google.bigtable.admin.v2.BigtableTableAdmin. CheckConsistency
Instance Attribute Summary collapse
-
#consistency_token ⇒ String
Required.
-
#data_boost_read_local_writes ⇒ Google::Apis::BigtableadminV2::DataBoostReadLocalWrites
Checks that all writes before the consistency token was generated in the same cluster are readable by Databoost.
-
#standard_read_remote_writes ⇒ Google::Apis::BigtableadminV2::StandardReadRemoteWrites
Checks that all writes before the consistency token was generated are replicated in every cluster and readable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CheckConsistencyRequest
constructor
A new instance of CheckConsistencyRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CheckConsistencyRequest
Returns a new instance of CheckConsistencyRequest.
602 603 604 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 602 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consistency_token ⇒ String
Required. The token created using GenerateConsistencyToken for the Table.
Corresponds to the JSON property consistencyToken
588 589 590 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 588 def consistency_token @consistency_token end |
#data_boost_read_local_writes ⇒ Google::Apis::BigtableadminV2::DataBoostReadLocalWrites
Checks that all writes before the consistency token was generated in the same
cluster are readable by Databoost.
Corresponds to the JSON property dataBoostReadLocalWrites
594 595 596 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 594 def data_boost_read_local_writes @data_boost_read_local_writes end |
#standard_read_remote_writes ⇒ Google::Apis::BigtableadminV2::StandardReadRemoteWrites
Checks that all writes before the consistency token was generated are
replicated in every cluster and readable.
Corresponds to the JSON property standardReadRemoteWrites
600 601 602 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 600 def standard_read_remote_writes @standard_read_remote_writes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
607 608 609 610 611 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 607 def update!(**args) @consistency_token = args[:consistency_token] if args.key?(:consistency_token) @data_boost_read_local_writes = args[:data_boost_read_local_writes] if args.key?(:data_boost_read_local_writes) @standard_read_remote_writes = args[:standard_read_remote_writes] if args.key?(:standard_read_remote_writes) end |