Class: Google::Apis::BigtableadminV2::Cluster

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

A resizable group of nodes in a particular cloud location, capable of serving all Tables in the parent Instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Cluster

Returns a new instance of Cluster.



688
689
690
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 688

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_configGoogle::Apis::BigtableadminV2::ClusterConfig

Configuration for a cluster. Corresponds to the JSON property clusterConfig



644
645
646
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 644

def cluster_config
  @cluster_config
end

#default_storage_typeString

Immutable. The type of storage used by this cluster to serve its parent instance's tables, unless explicitly overridden. Corresponds to the JSON property defaultStorageType

Returns:

  • (String)


650
651
652
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 650

def default_storage_type
  @default_storage_type
end

#encryption_configGoogle::Apis::BigtableadminV2::EncryptionConfig

Cloud Key Management Service (Cloud KMS) settings for a CMEK-protected cluster. Corresponds to the JSON property encryptionConfig



655
656
657
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 655

def encryption_config
  @encryption_config
end

#locationString

Immutable. The location where this cluster's nodes and storage reside. For best performance, clients should be located as close as possible to this cluster. Currently only zones are supported, so values should be of the form projects/project/locations/zone`. Corresponds to the JSON propertylocation`

Returns:

  • (String)


663
664
665
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 663

def location
  @location
end

#nameString

The unique name of the cluster. Values are of the form projects/project/ instances/instance/clusters/a-z*. Corresponds to the JSON property name

Returns:

  • (String)


669
670
671
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 669

def name
  @name
end

#node_scaling_factorString

Immutable. The node scaling factor of this cluster. Corresponds to the JSON property nodeScalingFactor

Returns:

  • (String)


674
675
676
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 674

def node_scaling_factor
  @node_scaling_factor
end

#serve_nodesFixnum

The number of nodes in the cluster. If no value is set, Cloud Bigtable automatically allocates nodes based on your data footprint and optimized for 50% storage utilization. Corresponds to the JSON property serveNodes

Returns:

  • (Fixnum)


681
682
683
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 681

def serve_nodes
  @serve_nodes
end

#stateString

Output only. The current state of the cluster. Corresponds to the JSON property state

Returns:

  • (String)


686
687
688
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 686

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



693
694
695
696
697
698
699
700
701
702
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 693

def update!(**args)
  @cluster_config = args[:cluster_config] if args.key?(:cluster_config)
  @default_storage_type = args[:default_storage_type] if args.key?(:default_storage_type)
  @encryption_config = args[:encryption_config] if args.key?(:encryption_config)
  @location = args[:location] if args.key?(:location)
  @name = args[:name] if args.key?(:name)
  @node_scaling_factor = args[:node_scaling_factor] if args.key?(:node_scaling_factor)
  @serve_nodes = args[:serve_nodes] if args.key?(:serve_nodes)
  @state = args[:state] if args.key?(:state)
end