Class: Google::Apis::BigtableadminV2::ColumnFamily

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

A set of columns within a table which share a common configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ColumnFamily

Returns a new instance of ColumnFamily.



815
816
817
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 815

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gc_ruleGoogle::Apis::BigtableadminV2::GcRule

Rule for determining which cells to delete during garbage collection. Corresponds to the JSON property gcRule



785
786
787
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 785

def gc_rule
  @gc_rule
end

#statsGoogle::Apis::BigtableadminV2::ColumnFamilyStats

Approximate statistics related to a single column family within a table. This information may change rapidly, interpreting these values at a point in time may already preset out-of-date information. Everything below is approximate, unless otherwise specified. Corresponds to the JSON property stats



793
794
795
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 793

def stats
  @stats
end

#value_typeGoogle::Apis::BigtableadminV2::Type

Type represents the type of data that is written to, read from, or stored in Bigtable. It is heavily based on the GoogleSQL standard to help maintain familiarity and consistency across products and features. For compatibility with Bigtable's existing untyped APIs, each Type includes an Encoding which describes how to convert to or from the underlying data. Each encoding can operate in one of two modes: - Sorted: In this mode, Bigtable guarantees that Encode(X) <= Encode(Y) if and only if X <= Y. This is useful anywhere sort order is important, for example when encoding keys. - Distinct: In this mode, Bigtable guarantees that if X != Y then Encode(X) != Encode(Y). However, the converse is not guaranteed. For example, both 'foo': '1', 'bar': '2' and 'bar': '2', 'foo': '1' are valid encodings of the same JSON value. The API clearly documents which mode is used wherever an encoding can be configured. Each encoding also documents which values are supported in which modes. For example, when encoding INT64 as a numeric STRING, negative numbers cannot be encoded in sorted mode. This is because INT64(1) > INT64(-1) , but STRING("-00001") > STRING("00001"). Corresponds to the JSON property valueType



813
814
815
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 813

def value_type
  @value_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



820
821
822
823
824
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 820

def update!(**args)
  @gc_rule = args[:gc_rule] if args.key?(:gc_rule)
  @stats = args[:stats] if args.key?(:stats)
  @value_type = args[:value_type] if args.key?(:value_type)
end