Class: Google::Apis::BigtableadminV2::ColumnFamilyStats
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::ColumnFamilyStats
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
Approximate statistics related to a single column family within a table. This information may change rapidly, interpreting these values at a point in time may already preset out-of-date information. Everything below is approximate, unless otherwise specified.
Instance Attribute Summary collapse
-
#average_cells_per_column ⇒ Float
How many cells are present per column qualifier in this column family, averaged over all rows containing any column in the column family.
-
#average_columns_per_row ⇒ Float
How many column qualifiers are present in this column family, averaged over all rows in the table.
-
#logical_data_bytes ⇒ Fixnum
How much space the data in the column family occupies.
-
#logical_data_hdd_bytes ⇒ Fixnum
Output only.
-
#logical_data_ssd_bytes ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ColumnFamilyStats
constructor
A new instance of ColumnFamilyStats.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ColumnFamilyStats
Returns a new instance of ColumnFamilyStats.
873 874 875 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 873 def initialize(**args) update!(**args) end |
Instance Attribute Details
#average_cells_per_column ⇒ Float
How many cells are present per column qualifier in this column family,
averaged over all rows containing any column in the column family. e.g. For
column family "family" in a table with 3 rows: * A row with 3 cells in "family:
col" and 1 cell in "other:col" (3 cells / 1 column in "family") * A row with 1
cell in "family:col", 7 cells in "family:other_col", and 7 cells in "other:
data" (8 cells / 2 columns in "family") * A row with 3 cells in "other:col" (0
columns in "family", "family" not present) would report (3 + 8 + 0)/(1 + 2 + 0)
= 3.66 in this field.
Corresponds to the JSON property averageCellsPerColumn
844 845 846 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 844 def average_cells_per_column @average_cells_per_column end |
#average_columns_per_row ⇒ Float
How many column qualifiers are present in this column family, averaged over all rows in the table. e.g. For column family "family" in a table with 3 rows:
- A row with cells in "family:col" and "other:col" (1 column in "family") * A
row with cells in "family:col", "family:other_col", and "other:data" (2
columns in "family") * A row with cells in "other:col" (0 columns in "family",
"family" not present) would report (1 + 2 + 0)/3 = 1.5 in this field.
Corresponds to the JSON property
averageColumnsPerRow
854 855 856 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 854 def average_columns_per_row @average_columns_per_row end |
#logical_data_bytes ⇒ Fixnum
How much space the data in the column family occupies. This is roughly how
many bytes would be needed to read the contents of the entire column family (e.
g. by streaming all contents out).
Corresponds to the JSON property logicalDataBytes
861 862 863 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 861 def logical_data_bytes @logical_data_bytes end |
#logical_data_hdd_bytes ⇒ Fixnum
Output only. The logical data bytes of the column family stored on HDD.
Corresponds to the JSON property logicalDataHddBytes
866 867 868 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 866 def logical_data_hdd_bytes @logical_data_hdd_bytes end |
#logical_data_ssd_bytes ⇒ Fixnum
Output only. The logical data bytes of the column family stored on SSD.
Corresponds to the JSON property logicalDataSsdBytes
871 872 873 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 871 def logical_data_ssd_bytes @logical_data_ssd_bytes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
878 879 880 881 882 883 884 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 878 def update!(**args) @average_cells_per_column = args[:average_cells_per_column] if args.key?(:average_cells_per_column) @average_columns_per_row = args[:average_columns_per_row] if args.key?(:average_columns_per_row) @logical_data_bytes = args[:logical_data_bytes] if args.key?(:logical_data_bytes) @logical_data_hdd_bytes = args[:logical_data_hdd_bytes] if args.key?(:logical_data_hdd_bytes) @logical_data_ssd_bytes = args[:logical_data_ssd_bytes] if args.key?(:logical_data_ssd_bytes) end |