Class: Google::Apis::BigtableadminV2::CreateClusterRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

Request message for BigtableInstanceAdmin.CreateCluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreateClusterRequest

Returns a new instance of CreateClusterRequest.



1142
1143
1144
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1142

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#clusterGoogle::Apis::BigtableadminV2::Cluster

A resizable group of nodes in a particular cloud location, capable of serving all Tables in the parent Instance. Corresponds to the JSON property cluster



1127
1128
1129
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1127

def cluster
  @cluster
end

#cluster_idString

Required. The ID to be used when referring to the new cluster within its instance, e.g., just mycluster rather than projects/myproject/instances/ myinstance/clusters/mycluster. Corresponds to the JSON property clusterId

Returns:

  • (String)


1134
1135
1136
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1134

def cluster_id
  @cluster_id
end

#parentString

Required. The unique name of the instance in which to create the new cluster. Values are of the form projects/project/instances/instance`. Corresponds to the JSON propertyparent`

Returns:

  • (String)


1140
1141
1142
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1140

def parent
  @parent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1147
1148
1149
1150
1151
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1147

def update!(**args)
  @cluster = args[:cluster] if args.key?(:cluster)
  @cluster_id = args[:cluster_id] if args.key?(:cluster_id)
  @parent = args[:parent] if args.key?(:parent)
end