Class: Google::Apis::BigtableadminV2::CreateLogicalViewMetadata
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::CreateLogicalViewMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
The metadata for the Operation returned by CreateLogicalView.
Instance Attribute Summary collapse
-
#end_time ⇒ String
DEPRECATED: Use finish_time instead.
-
#finish_time ⇒ String
The time at which the operation failed or was completed successfully.
-
#original_request ⇒ Google::Apis::BigtableadminV2::CreateLogicalViewRequest
Request message for BigtableInstanceAdmin.CreateLogicalView.
-
#request_time ⇒ String
The time at which the original request was received.
-
#start_time ⇒ String
DEPRECATED: Use request_time instead.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CreateLogicalViewMetadata
constructor
A new instance of CreateLogicalViewMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CreateLogicalViewMetadata
Returns a new instance of CreateLogicalViewMetadata.
1245 1246 1247 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1245 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
DEPRECATED: Use finish_time instead.
Corresponds to the JSON property endTime
1223 1224 1225 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1223 def end_time @end_time end |
#finish_time ⇒ String
The time at which the operation failed or was completed successfully.
Corresponds to the JSON property finishTime
1228 1229 1230 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1228 def finish_time @finish_time end |
#original_request ⇒ Google::Apis::BigtableadminV2::CreateLogicalViewRequest
Request message for BigtableInstanceAdmin.CreateLogicalView.
Corresponds to the JSON property originalRequest
1233 1234 1235 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1233 def original_request @original_request end |
#request_time ⇒ String
The time at which the original request was received.
Corresponds to the JSON property requestTime
1238 1239 1240 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1238 def request_time @request_time end |
#start_time ⇒ String
DEPRECATED: Use request_time instead.
Corresponds to the JSON property startTime
1243 1244 1245 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1243 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1250 1251 1252 1253 1254 1255 1256 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1250 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @finish_time = args[:finish_time] if args.key?(:finish_time) @original_request = args[:original_request] if args.key?(:original_request) @request_time = args[:request_time] if args.key?(:request_time) @start_time = args[:start_time] if args.key?(:start_time) end |