Class: Google::Apis::BigtableadminV2::CreateTableRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

Request message for google.bigtable.admin.v2.BigtableTableAdmin.CreateTable

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreateTableRequest

Returns a new instance of CreateTableRequest.



1432
1433
1434
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1432

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#initial_splitsArray<Google::Apis::BigtableadminV2::Split>

The optional list of row keys that will be used to initially split the table into several tablets (tablets are similar to HBase regions). Given two split keys, s1 and s2, three tablets will be created, spanning the key ranges: [ , s1), [s1, s2), [s2, ). Example: * Row keys := ["a", "apple", "custom", " customer_1", "customer_2", "other", "zz"] * initial_split_keys := ["apple", "customer_1", "customer_2", "other"] * Key assignment: - Tablet 1 [, apple) =>"a". - Tablet 2 [apple, customer_1) =>"apple", "custom". - Tablet 3 [customer_1, customer_2) =>"customer_1". - Tablet 4 `[customer_2, other) =

"customer_2".- Tablet 5[other, ) => "other", "zz". Corresponds to the JSON propertyinitialSplits`



1417
1418
1419
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1417

def initial_splits
  @initial_splits
end

#tableGoogle::Apis::BigtableadminV2::Table

A collection of user data indexed by row, column, and timestamp. Each table is served using the resources of its parent cluster. Corresponds to the JSON property table



1423
1424
1425
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1423

def table
  @table
end

#table_idString

Required. The name by which the new table should be referred to within the parent instance, e.g., foobar rather than `parent/tables/foobar. Maximum 50 characters. Corresponds to the JSON propertytableId`

Returns:

  • (String)


1430
1431
1432
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1430

def table_id
  @table_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1437
1438
1439
1440
1441
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1437

def update!(**args)
  @initial_splits = args[:initial_splits] if args.key?(:initial_splits)
  @table = args[:table] if args.key?(:table)
  @table_id = args[:table_id] if args.key?(:table_id)
end