Class: Google::Apis::BigtableadminV2::EncryptionConfig
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::EncryptionConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
Cloud Key Management Service (Cloud KMS) settings for a CMEK-protected cluster.
Instance Attribute Summary collapse
-
#kms_key_name ⇒ String
Describes the Cloud KMS encryption key that will be used to protect the destination Bigtable cluster.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EncryptionConfig
constructor
A new instance of EncryptionConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EncryptionConfig
Returns a new instance of EncryptionConfig.
1559 1560 1561 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1559 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kms_key_name ⇒ String
Describes the Cloud KMS encryption key that will be used to protect the
destination Bigtable cluster. The requirements for this key are: 1) The Cloud
Bigtable service account associated with the project that contains this
cluster must be granted the cloudkms.cryptoKeyEncrypterDecrypter role on the
CMEK key. 2) Only regional keys can be used and the region of the CMEK key
must match the region of the cluster. Values are of the form projects/
project/locations/location/keyRings/keyring/cryptoKeys/key`
Corresponds to the JSON propertykmsKeyName`
1557 1558 1559 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1557 def kms_key_name @kms_key_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1564 1565 1566 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1564 def update!(**args) @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name) end |