Class: Google::Apis::BigtableadminV2::EncryptionInfo
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::EncryptionInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
Encryption information for a given resource. If this resource is protected with customer managed encryption, the in-use Cloud Key Management Service ( Cloud KMS) key version is specified along with its status.
Instance Attribute Summary collapse
-
#encryption_status ⇒ Google::Apis::BigtableadminV2::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#encryption_type ⇒ String
Output only.
-
#kms_key_version ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EncryptionInfo
constructor
A new instance of EncryptionInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EncryptionInfo
Returns a new instance of EncryptionInfo.
1596 1597 1598 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1596 def initialize(**args) update!(**args) end |
Instance Attribute Details
#encryption_status ⇒ Google::Apis::BigtableadminV2::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property encryptionStatus
1583 1584 1585 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1583 def encryption_status @encryption_status end |
#encryption_type ⇒ String
Output only. The type of encryption used to protect this resource.
Corresponds to the JSON property encryptionType
1588 1589 1590 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1588 def encryption_type @encryption_type end |
#kms_key_version ⇒ String
Output only. The version of the Cloud KMS key specified in the parent cluster
that is in use for the data underlying this table.
Corresponds to the JSON property kmsKeyVersion
1594 1595 1596 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1594 def kms_key_version @kms_key_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1601 1602 1603 1604 1605 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1601 def update!(**args) @encryption_status = args[:encryption_status] if args.key?(:encryption_status) @encryption_type = args[:encryption_type] if args.key?(:encryption_type) @kms_key_version = args[:kms_key_version] if args.key?(:kms_key_version) end |