Class: Google::Apis::BigtableadminV2::GcRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

Rule for determining which cells to delete during garbage collection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GcRule

Returns a new instance of GcRule.



1667
1668
1669
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1667

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#intersectionGoogle::Apis::BigtableadminV2::Intersection

A GcRule which deletes cells matching all of the given rules. Corresponds to the JSON property intersection



1649
1650
1651
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1649

def intersection
  @intersection
end

#max_ageString

Delete cells in a column older than the given age. Values must be at least one millisecond, and will be truncated to microsecond granularity. Corresponds to the JSON property maxAge

Returns:

  • (String)


1655
1656
1657
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1655

def max_age
  @max_age
end

#max_num_versionsFixnum

Delete all cells in a column except the most recent N. Corresponds to the JSON property maxNumVersions

Returns:

  • (Fixnum)


1660
1661
1662
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1660

def max_num_versions
  @max_num_versions
end

#unionGoogle::Apis::BigtableadminV2::Union

A GcRule which deletes cells matching any of the given rules. Corresponds to the JSON property union



1665
1666
1667
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1665

def union
  @union
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1672
1673
1674
1675
1676
1677
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1672

def update!(**args)
  @intersection = args[:intersection] if args.key?(:intersection)
  @max_age = args[:max_age] if args.key?(:max_age)
  @max_num_versions = args[:max_num_versions] if args.key?(:max_num_versions)
  @union = args[:union] if args.key?(:union)
end