Class: Google::Apis::BigtableadminV2::GoogleBigtableAdminV2AuthorizedViewSubsetView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

Defines a simple AuthorizedView that is a subset of the underlying Table.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleBigtableAdminV2AuthorizedViewSubsetView

Returns a new instance of GoogleBigtableAdminV2AuthorizedViewSubsetView.



1795
1796
1797
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1795

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#family_subsetsHash<String,Google::Apis::BigtableadminV2::GoogleBigtableAdminV2AuthorizedViewFamilySubsets>

Map from column family name to the columns in this family to be included in the AuthorizedView. Corresponds to the JSON property familySubsets



1787
1788
1789
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1787

def family_subsets
  @family_subsets
end

#row_prefixesArray<String>

Row prefixes to be included in the AuthorizedView. To provide access to all rows, include the empty string as a prefix (""). Corresponds to the JSON property rowPrefixes

Returns:

  • (Array<String>)


1793
1794
1795
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1793

def row_prefixes
  @row_prefixes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1800
1801
1802
1803
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1800

def update!(**args)
  @family_subsets = args[:family_subsets] if args.key?(:family_subsets)
  @row_prefixes = args[:row_prefixes] if args.key?(:row_prefixes)
end