Class: Google::Apis::BigtableadminV2::GoogleBigtableAdminV2TypeBytes

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

Bytes Values of type Bytes are stored in Value.bytes_value.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleBigtableAdminV2TypeBytes

Returns a new instance of GoogleBigtableAdminV2TypeBytes.



2096
2097
2098
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2096

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#encodingGoogle::Apis::BigtableadminV2::GoogleBigtableAdminV2TypeBytesEncoding

Rules used to convert to or from lower level types. Corresponds to the JSON property encoding



2094
2095
2096
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2094

def encoding
  @encoding
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2101
2102
2103
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2101

def update!(**args)
  @encoding = args[:encoding] if args.key?(:encoding)
end