Class: Google::Apis::BigtableadminV2::GoogleBigtableAdminV2TypeInt32Encoding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

Rules used to convert to or from lower level types.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleBigtableAdminV2TypeInt32Encoding

Returns a new instance of GoogleBigtableAdminV2TypeInt32Encoding.



2246
2247
2248
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2246

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#big_endian_bytesGoogle::Apis::BigtableadminV2::GoogleBigtableAdminV2TypeInt32EncodingBigEndianBytes

Encodes the value as a 4-byte big-endian two's complement value. Sorted mode: non-negative values are supported. Distinct mode: all values are supported. Compatible with: - BigQuery BINARY encoding - HBase Bytes.toBytes - Java ByteBuffer.putInt() with ByteOrder.BIG_ENDIAN Corresponds to the JSON property bigEndianBytes



2237
2238
2239
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2237

def big_endian_bytes
  @big_endian_bytes
end

#ordered_code_bytesGoogle::Apis::BigtableadminV2::GoogleBigtableAdminV2TypeInt32EncodingOrderedCodeBytes

Encodes the value in a variable length binary format of up to 5 bytes. Values that are closer to zero use fewer bytes. Sorted mode: all values are supported. Distinct mode: all values are supported. Corresponds to the JSON property orderedCodeBytes



2244
2245
2246
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2244

def ordered_code_bytes
  @ordered_code_bytes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2251
2252
2253
2254
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2251

def update!(**args)
  @big_endian_bytes = args[:big_endian_bytes] if args.key?(:big_endian_bytes)
  @ordered_code_bytes = args[:ordered_code_bytes] if args.key?(:ordered_code_bytes)
end