Class: Google::Apis::BigtableadminV2::GoogleBigtableAdminV2TypeInt64Encoding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

Rules used to convert to or from lower level types.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleBigtableAdminV2TypeInt64Encoding

Returns a new instance of GoogleBigtableAdminV2TypeInt64Encoding.



2185
2186
2187
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2185

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#big_endian_bytesGoogle::Apis::BigtableadminV2::GoogleBigtableAdminV2TypeInt64EncodingBigEndianBytes

Encodes the value as an 8-byte big-endian two's complement value. Sorted mode: non-negative values are supported. Distinct mode: all values are supported. Compatible with: - BigQuery BINARY encoding - HBase Bytes.toBytes - Java ByteBuffer.putLong() with ByteOrder.BIG_ENDIAN Corresponds to the JSON property bigEndianBytes



2176
2177
2178
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2176

def big_endian_bytes
  @big_endian_bytes
end

#ordered_code_bytesGoogle::Apis::BigtableadminV2::GoogleBigtableAdminV2TypeInt64EncodingOrderedCodeBytes

Encodes the value in a variable length binary format of up to 10 bytes. Values that are closer to zero use fewer bytes. Sorted mode: all values are supported. Distinct mode: all values are supported. Corresponds to the JSON property orderedCodeBytes



2183
2184
2185
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2183

def ordered_code_bytes
  @ordered_code_bytes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2190
2191
2192
2193
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2190

def update!(**args)
  @big_endian_bytes = args[:big_endian_bytes] if args.key?(:big_endian_bytes)
  @ordered_code_bytes = args[:ordered_code_bytes] if args.key?(:ordered_code_bytes)
end