Class: Google::Apis::BigtableadminV2::GoogleBigtableAdminV2TypeInt64EncodingOrderedCodeBytes
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::GoogleBigtableAdminV2TypeInt64EncodingOrderedCodeBytes
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
Encodes the value in a variable length binary format of up to 10 bytes. Values that are closer to zero use fewer bytes. Sorted mode: all values are supported. Distinct mode: all values are supported.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleBigtableAdminV2TypeInt64EncodingOrderedCodeBytes
constructor
A new instance of GoogleBigtableAdminV2TypeInt64EncodingOrderedCodeBytes.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleBigtableAdminV2TypeInt64EncodingOrderedCodeBytes
Returns a new instance of GoogleBigtableAdminV2TypeInt64EncodingOrderedCodeBytes.
2224 2225 2226 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2224 def initialize(**args) update!(**args) end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2229 2230 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2229 def update!(**args) end |