Class: Google::Apis::BigtableadminV2::GoogleBigtableAdminV2TypeProto

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

A protobuf message type. Values of type Proto are stored in Value. bytes_value.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleBigtableAdminV2TypeProto

Returns a new instance of GoogleBigtableAdminV2TypeProto.



2470
2471
2472
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2470

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#message_nameString

The fully qualified name of the protobuf message, including package. In the format of "foo.bar.Message". Corresponds to the JSON property messageName

Returns:

  • (String)


2463
2464
2465
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2463

def message_name
  @message_name
end

#schema_bundle_idString

The ID of the schema bundle that this proto is defined in. Corresponds to the JSON property schemaBundleId

Returns:

  • (String)


2468
2469
2470
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2468

def schema_bundle_id
  @schema_bundle_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2475
2476
2477
2478
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2475

def update!(**args)
  @message_name = args[:message_name] if args.key?(:message_name)
  @schema_bundle_id = args[:schema_bundle_id] if args.key?(:schema_bundle_id)
end