Class: Google::Apis::BigtableadminV2::GoogleBigtableAdminV2TypeStringEncodingUtf8Bytes

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

UTF-8 encoding. Sorted mode: - All values are supported. - Code point order is preserved. Distinct mode: all values are supported. Compatible with: - BigQuery TEXT encoding - HBase Bytes.toBytes - Java String#getBytes( StandardCharsets.UTF_8)

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleBigtableAdminV2TypeStringEncodingUtf8Bytes

Returns a new instance of GoogleBigtableAdminV2TypeStringEncodingUtf8Bytes.



2525
2526
2527
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2525

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#null_escape_charString

Single-character escape sequence used to support NULL values. If set, allows NULL values to be encoded as the empty string "". The actual empty string, or any value where every character equals null_escape_char, has one more null_escape_char appended. If null_escape_char is set and does not equal the ASCII null character 0x00, then the encoding will not support sorted mode. . Corresponds to the JSON property nullEscapeChar

Returns:

  • (String)


2523
2524
2525
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2523

def null_escape_char
  @null_escape_char
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2530
2531
2532
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2530

def update!(**args)
  @null_escape_char = args[:null_escape_char] if args.key?(:null_escape_char)
end