Class: Google::Apis::BigtableadminV2::GoogleBigtableAdminV2TypeStruct

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

A structured data value, consisting of fields which map to dynamically typed values. Values of type Struct are stored in Value.array_value where entries are in the same order and number as field_types.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleBigtableAdminV2TypeStruct

Returns a new instance of GoogleBigtableAdminV2TypeStruct.



2584
2585
2586
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2584

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#encodingGoogle::Apis::BigtableadminV2::GoogleBigtableAdminV2TypeStructEncoding

Rules used to convert to or from lower level types. Corresponds to the JSON property encoding



2577
2578
2579
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2577

def encoding
  @encoding
end

#fieldsArray<Google::Apis::BigtableadminV2::GoogleBigtableAdminV2TypeStructField>

The names and types of the fields in this struct. Corresponds to the JSON property fields



2582
2583
2584
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2582

def fields
  @fields
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2589
2590
2591
2592
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2589

def update!(**args)
  @encoding = args[:encoding] if args.key?(:encoding)
  @fields = args[:fields] if args.key?(:fields)
end