Class: Google::Apis::BigtableadminV2::GoogleBigtableAdminV2TypeStructField
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::GoogleBigtableAdminV2TypeStructField
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
A struct field and its type.
Instance Attribute Summary collapse
-
#field_name ⇒ String
The field name (optional).
-
#type ⇒ Google::Apis::BigtableadminV2::Type
Typerepresents the type of data that is written to, read from, or stored in Bigtable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleBigtableAdminV2TypeStructField
constructor
A new instance of GoogleBigtableAdminV2TypeStructField.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleBigtableAdminV2TypeStructField
Returns a new instance of GoogleBigtableAdminV2TypeStructField.
2749 2750 2751 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2749 def initialize(**args) update!(**args) end |
Instance Attribute Details
#field_name ⇒ String
The field name (optional). Fields without a field_name are considered
anonymous and cannot be referenced by name.
Corresponds to the JSON property fieldName
2727 2728 2729 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2727 def field_name @field_name end |
#type ⇒ Google::Apis::BigtableadminV2::Type
Type represents the type of data that is written to, read from, or stored in
Bigtable. It is heavily based on the GoogleSQL standard to help maintain
familiarity and consistency across products and features. For compatibility
with Bigtable's existing untyped APIs, each Type includes an Encoding
which describes how to convert to or from the underlying data. Each encoding
can operate in one of two modes: - Sorted: In this mode, Bigtable guarantees
that Encode(X) <= Encode(Y) if and only if X <= Y. This is useful anywhere
sort order is important, for example when encoding keys. - Distinct: In this
mode, Bigtable guarantees that if X != Y then Encode(X) != Encode(Y).
However, the converse is not guaranteed. For example, both 'foo': '1', 'bar':
'2' and 'bar': '2', 'foo': '1' are valid encodings of the same JSON
value. The API clearly documents which mode is used wherever an encoding can
be configured. Each encoding also documents which values are supported in
which modes. For example, when encoding INT64 as a numeric STRING, negative
numbers cannot be encoded in sorted mode. This is because INT64(1) > INT64(-1)
, but STRING("-00001") > STRING("00001").
Corresponds to the JSON property type
2747 2748 2749 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2747 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2754 2755 2756 2757 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2754 def update!(**args) @field_name = args[:field_name] if args.key?(:field_name) @type = args[:type] if args.key?(:type) end |