Class: Google::Apis::BigtableadminV2::GoogleBigtableAdminV2TypeTimestamp

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

Timestamp Values of type Timestamp are stored in Value.timestamp_value.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleBigtableAdminV2TypeTimestamp

Returns a new instance of GoogleBigtableAdminV2TypeTimestamp.



2628
2629
2630
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2628

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#encodingGoogle::Apis::BigtableadminV2::GoogleBigtableAdminV2TypeTimestampEncoding

Rules used to convert to or from lower level types. Corresponds to the JSON property encoding



2626
2627
2628
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2626

def encoding
  @encoding
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2633
2634
2635
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2633

def update!(**args)
  @encoding = args[:encoding] if args.key?(:encoding)
end