Class: Google::Apis::BigtableadminV2::ListInstancesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

Response message for BigtableInstanceAdmin.ListInstances.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListInstancesResponse

Returns a new instance of ListInstancesResponse.



3173
3174
3175
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3173

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#failed_locationsArray<String>

Locations from which Instance information could not be retrieved, due to an outage or some other transient condition. Instances whose Clusters are all in one of the failed locations may be missing from instances, and Instances with at least one Cluster in a failed location may only have partial information returned. Values are of the form projects//locations/ Corresponds to the JSON property failedLocations

Returns:

  • (Array<String>)


3161
3162
3163
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3161

def failed_locations
  @failed_locations
end

#instancesArray<Google::Apis::BigtableadminV2::Instance>

The list of requested instances. Corresponds to the JSON property instances



3166
3167
3168
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3166

def instances
  @instances
end

#next_page_tokenString

DEPRECATED: This field is unused and ignored. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3171
3172
3173
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3171

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3178
3179
3180
3181
3182
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3178

def update!(**args)
  @failed_locations = args[:failed_locations] if args.key?(:failed_locations)
  @instances = args[:instances] if args.key?(:instances)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end