Class: Google::Apis::BigtableadminV2::ListMemoryLayersResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

Response message for BigtableInstanceAdmin.ListMemoryLayers.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListMemoryLayersResponse

Returns a new instance of ListMemoryLayersResponse.



3285
3286
3287
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3285

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#failed_locationsArray<String>

Locations from which MemoryLayer information could not be retrieved, due to an outage or some other transient condition. MemoryLayers from these locations may be missing from memory_layers, or may only have partial information returned. Values are of the form projects//locations/ Corresponds to the JSON property failedLocations

Returns:

  • (Array<String>)


3272
3273
3274
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3272

def failed_locations
  @failed_locations
end

#memory_layersArray<Google::Apis::BigtableadminV2::MemoryLayer>

The list of requested memory layers. Corresponds to the JSON property memoryLayers



3277
3278
3279
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3277

def memory_layers
  @memory_layers
end

#next_page_tokenString

A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3283
3284
3285
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3283

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3290
3291
3292
3293
3294
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3290

def update!(**args)
  @failed_locations = args[:failed_locations] if args.key?(:failed_locations)
  @memory_layers = args[:memory_layers] if args.key?(:memory_layers)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end