Class: Google::Apis::BigtableadminV2::ListTablesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

Response message for google.bigtable.admin.v2.BigtableTableAdmin.ListTables

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListTablesResponse

Returns a new instance of ListTablesResponse.



3177
3178
3179
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3177

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

Set if not all tables could be returned in a single response. Pass this value to page_token in another request to get the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3170
3171
3172
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3170

def next_page_token
  @next_page_token
end

#tablesArray<Google::Apis::BigtableadminV2::Table>

The tables present in the requested instance. Corresponds to the JSON property tables



3175
3176
3177
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3175

def tables
  @tables
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3182
3183
3184
3185
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3182

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @tables = args[:tables] if args.key?(:tables)
end