Class: Google::Apis::BigtableadminV2::MemoryLayer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

The memory layer of a cluster. A memory layer serves reads from memory without hitting the backing persistent data store.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MemoryLayer

Returns a new instance of MemoryLayer.



3570
3571
3572
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3570

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Optional. The etag for this memory layer. This may be sent on update requests to ensure that the client has an up-to-date value before proceeding. The server returns an ABORTED error on a mismatched etag. Corresponds to the JSON property etag

Returns:

  • (String)


3552
3553
3554
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3552

def etag
  @etag
end

#memory_configGoogle::Apis::BigtableadminV2::GoogleBigtableAdminV2MemoryLayerMemoryConfig

Configuration of a memory layer. Corresponds to the JSON property memoryConfig



3557
3558
3559
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3557

def memory_config
  @memory_config
end

#nameString

Identifier. Name of the memory layer. This is always: "projects/project/ instances/instance/clusters/cluster/memoryLayer". Corresponds to the JSON property name

Returns:

  • (String)


3563
3564
3565
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3563

def name
  @name
end

#stateString

Output only. The current state of the memory layer. Corresponds to the JSON property state

Returns:

  • (String)


3568
3569
3570
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3568

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3575
3576
3577
3578
3579
3580
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3575

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @memory_config = args[:memory_config] if args.key?(:memory_config)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
end