Class: Google::Apis::BigtableadminV2::Modification

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

A create, update, or delete of a particular column family.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Modification

Returns a new instance of Modification.



3616
3617
3618
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3616

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::BigtableadminV2::ColumnFamily

A set of columns within a table which share a common configuration. Corresponds to the JSON property create



3590
3591
3592
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3590

def create
  @create
end

#dropBoolean Also known as: drop?

Drop (delete) the column family with the given ID, or fail if no such family exists. Corresponds to the JSON property drop

Returns:

  • (Boolean)


3596
3597
3598
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3596

def drop
  @drop
end

#idString

The ID of the column family to be modified. Corresponds to the JSON property id

Returns:

  • (String)


3602
3603
3604
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3602

def id
  @id
end

#updateGoogle::Apis::BigtableadminV2::ColumnFamily

A set of columns within a table which share a common configuration. Corresponds to the JSON property update



3607
3608
3609
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3607

def update
  @update
end

#update_maskString

Optional. A mask specifying which fields (e.g. gc_rule) in the update mod should be updated, ignored for other modification types. If unset or empty, we treat it as updating gc_rule to be backward compatible. Corresponds to the JSON property updateMask

Returns:

  • (String)


3614
3615
3616
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3614

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3621
3622
3623
3624
3625
3626
3627
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3621

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @drop = args[:drop] if args.key?(:drop)
  @id = args[:id] if args.key?(:id)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end