Class: Google::Apis::BigtableadminV2::OperationProgress

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

Encapsulates progress related information for a Cloud Bigtable long running operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationProgress

Returns a new instance of OperationProgress.



3780
3781
3782
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3780

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_timeString

If set, the time at which this operation failed or was completed successfully. Corresponds to the JSON property endTime

Returns:

  • (String)


3768
3769
3770
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3768

def end_time
  @end_time
end

#progress_percentFixnum

Percent completion of the operation. Values are between 0 and 100 inclusive. Corresponds to the JSON property progressPercent

Returns:

  • (Fixnum)


3773
3774
3775
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3773

def progress_percent
  @progress_percent
end

#start_timeString

Time the request was received. Corresponds to the JSON property startTime

Returns:

  • (String)


3778
3779
3780
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3778

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3785
3786
3787
3788
3789
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3785

def update!(**args)
  @end_time = args[:end_time] if args.key?(:end_time)
  @progress_percent = args[:progress_percent] if args.key?(:progress_percent)
  @start_time = args[:start_time] if args.key?(:start_time)
end