Class: Google::Apis::BigtableadminV2::PartialUpdateClusterRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

Request message for BigtableInstanceAdmin.PartialUpdateCluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PartialUpdateClusterRequest

Returns a new instance of PartialUpdateClusterRequest.



3840
3841
3842
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3840

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#clusterGoogle::Apis::BigtableadminV2::Cluster

A resizable group of nodes in a particular cloud location, capable of serving all Tables in the parent Instance. Corresponds to the JSON property cluster



3833
3834
3835
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3833

def cluster
  @cluster
end

#update_maskString

Required. The subset of Cluster fields which should be replaced. Corresponds to the JSON property updateMask

Returns:

  • (String)


3838
3839
3840
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3838

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3845
3846
3847
3848
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3845

def update!(**args)
  @cluster = args[:cluster] if args.key?(:cluster)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end