Class: Google::Apis::BigtableadminV2::RestoreTableMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

Metadata type for the long-running operation returned by RestoreTable.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RestoreTableMetadata

Returns a new instance of RestoreTableMetadata.



4090
4091
4092
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4090

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backup_infoGoogle::Apis::BigtableadminV2::BackupInfo

Information about a backup. Corresponds to the JSON property backupInfo



4060
4061
4062
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4060

def backup_info
  @backup_info
end

#nameString

Name of the table being created and restored to. Corresponds to the JSON property name

Returns:

  • (String)


4065
4066
4067
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4065

def name
  @name
end

#optimize_table_operation_nameString

If exists, the name of the long-running operation that will be used to track the post-restore optimization process to optimize the performance of the restored table. The metadata type of the long-running operation is OptimizeRestoredTableMetadata. The response type is Empty. This long-running operation may be automatically created by the system if applicable after the RestoreTable long-running operation completes successfully. This operation may not be created if the table is already optimized or the restore was not successful. Corresponds to the JSON property optimizeTableOperationName

Returns:

  • (String)


4077
4078
4079
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4077

def optimize_table_operation_name
  @optimize_table_operation_name
end

#progressGoogle::Apis::BigtableadminV2::OperationProgress

Encapsulates progress related information for a Cloud Bigtable long running operation. Corresponds to the JSON property progress



4083
4084
4085
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4083

def progress
  @progress
end

#source_typeString

The type of the restore source. Corresponds to the JSON property sourceType

Returns:

  • (String)


4088
4089
4090
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4088

def source_type
  @source_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4095
4096
4097
4098
4099
4100
4101
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4095

def update!(**args)
  @backup_info = args[:backup_info] if args.key?(:backup_info)
  @name = args[:name] if args.key?(:name)
  @optimize_table_operation_name = args[:optimize_table_operation_name] if args.key?(:optimize_table_operation_name)
  @progress = args[:progress] if args.key?(:progress)
  @source_type = args[:source_type] if args.key?(:source_type)
end