Class: Google::Apis::BigtableadminV2::Split

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

An initial split point for a newly created table.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Split

Returns a new instance of Split.



4281
4282
4283
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4281

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#keyString

Row key to use as an initial tablet boundary. Corresponds to the JSON property key NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


4279
4280
4281
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4279

def key
  @key
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4286
4287
4288
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4286

def update!(**args)
  @key = args[:key] if args.key?(:key)
end