Class: Google::Apis::BigtableadminV2::TieredStorageRule

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

Rule to specify what data is stored in a storage tier.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TieredStorageRule

Returns a new instance of TieredStorageRule.



4609
4610
4611
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4609

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#include_if_older_thanString

Include cells older than the given age. For the infrequent access tier, this value must be at least 30 days. Corresponds to the JSON property includeIfOlderThan

Returns:

  • (String)


4607
4608
4609
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4607

def include_if_older_than
  @include_if_older_than
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4614
4615
4616
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4614

def update!(**args)
  @include_if_older_than = args[:include_if_older_than] if args.key?(:include_if_older_than)
end