Class: Google::Apis::BigtableadminV2::UndeleteTableMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

Metadata type for the operation returned by google.bigtable.admin.v2. BigtableTableAdmin.UndeleteTable.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UndeleteTableMetadata

Returns a new instance of UndeleteTableMetadata.



4786
4787
4788
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4786

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_timeString

If set, the time at which this operation finished or was cancelled. DEPRECATED: Use finish_time instead. Corresponds to the JSON property endTime

Returns:

  • (String)


4764
4765
4766
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4764

def end_time
  @end_time
end

#finish_timeString

The time at which the operation failed or was completed successfully. Corresponds to the JSON property finishTime

Returns:

  • (String)


4769
4770
4771
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4769

def finish_time
  @finish_time
end

#nameString

The name of the table being restored. Corresponds to the JSON property name

Returns:

  • (String)


4774
4775
4776
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4774

def name
  @name
end

#request_timeString

The time at which the original request was received. Corresponds to the JSON property requestTime

Returns:

  • (String)


4779
4780
4781
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4779

def request_time
  @request_time
end

#start_timeString

The time at which this operation started. DEPRECATED: Use request_time instead. Corresponds to the JSON property startTime

Returns:

  • (String)


4784
4785
4786
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4784

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4791
4792
4793
4794
4795
4796
4797
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4791

def update!(**args)
  @end_time = args[:end_time] if args.key?(:end_time)
  @finish_time = args[:finish_time] if args.key?(:finish_time)
  @name = args[:name] if args.key?(:name)
  @request_time = args[:request_time] if args.key?(:request_time)
  @start_time = args[:start_time] if args.key?(:start_time)
end