Class: Google::Apis::BigtableadminV2::UpdateAuthorizedViewMetadata
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::UpdateAuthorizedViewMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
Metadata for the google.longrunning.Operation returned by UpdateAuthorizedView.
Instance Attribute Summary collapse
-
#finish_time ⇒ String
The time at which the operation failed or was completed successfully.
-
#original_request ⇒ Google::Apis::BigtableadminV2::UpdateAuthorizedViewRequest
The request for UpdateAuthorizedView.
-
#request_time ⇒ String
The time at which the original request was received.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpdateAuthorizedViewMetadata
constructor
A new instance of UpdateAuthorizedViewMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpdateAuthorizedViewMetadata
Returns a new instance of UpdateAuthorizedViewMetadata.
4597 4598 4599 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4597 def initialize(**args) update!(**args) end |
Instance Attribute Details
#finish_time ⇒ String
The time at which the operation failed or was completed successfully.
Corresponds to the JSON property finishTime
4585 4586 4587 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4585 def finish_time @finish_time end |
#original_request ⇒ Google::Apis::BigtableadminV2::UpdateAuthorizedViewRequest
The request for UpdateAuthorizedView.
Corresponds to the JSON property originalRequest
4590 4591 4592 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4590 def original_request @original_request end |
#request_time ⇒ String
The time at which the original request was received.
Corresponds to the JSON property requestTime
4595 4596 4597 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4595 def request_time @request_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4602 4603 4604 4605 4606 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4602 def update!(**args) @finish_time = args[:finish_time] if args.key?(:finish_time) @original_request = args[:original_request] if args.key?(:original_request) @request_time = args[:request_time] if args.key?(:request_time) end |