Class: Google::Apis::BigtableadminV2::UpdateAuthorizedViewRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

The request for UpdateAuthorizedView.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpdateAuthorizedViewRequest

Returns a new instance of UpdateAuthorizedViewRequest.



4894
4895
4896
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4894

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authorized_viewGoogle::Apis::BigtableadminV2::AuthorizedView

An Authorized View of a Cloud Bigtable Table. Corresponds to the JSON property authorizedView



4876
4877
4878
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4876

def authorized_view
  @authorized_view
end

#ignore_warningsBoolean Also known as: ignore_warnings?

Optional. If true, ignore the safety checks when updating the AuthorizedView. Corresponds to the JSON property ignoreWarnings

Returns:

  • (Boolean)


4881
4882
4883
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4881

def ignore_warnings
  @ignore_warnings
end

#update_maskString

Optional. The list of fields to update. A mask specifying which fields in the AuthorizedView resource should be updated. This mask is relative to the AuthorizedView resource, not to the request message. A field will be overwritten if it is in the mask. If empty, all fields set in the request will be overwritten. A special value * means to overwrite all fields (including fields not set in the request). Corresponds to the JSON property updateMask

Returns:

  • (String)


4892
4893
4894
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4892

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4899
4900
4901
4902
4903
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4899

def update!(**args)
  @authorized_view = args[:authorized_view] if args.key?(:authorized_view)
  @ignore_warnings = args[:ignore_warnings] if args.key?(:ignore_warnings)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end