Class: Google::Apis::BigtableadminV2::UpdateLogicalViewMetadata
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::UpdateLogicalViewMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
The metadata for the Operation returned by UpdateLogicalView.
Instance Attribute Summary collapse
-
#end_time ⇒ String
DEPRECATED: Use finish_time instead.
-
#finish_time ⇒ String
The time at which the operation failed or was completed successfully.
-
#original_request ⇒ Google::Apis::BigtableadminV2::UpdateLogicalViewRequest
Request message for BigtableInstanceAdmin.UpdateLogicalView.
-
#request_time ⇒ String
The time at which the original request was received.
-
#start_time ⇒ String
DEPRECATED: Use request_time instead.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpdateLogicalViewMetadata
constructor
A new instance of UpdateLogicalViewMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpdateLogicalViewMetadata
Returns a new instance of UpdateLogicalViewMetadata.
5025 5026 5027 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 5025 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
DEPRECATED: Use finish_time instead.
Corresponds to the JSON property endTime
5003 5004 5005 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 5003 def end_time @end_time end |
#finish_time ⇒ String
The time at which the operation failed or was completed successfully.
Corresponds to the JSON property finishTime
5008 5009 5010 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 5008 def finish_time @finish_time end |
#original_request ⇒ Google::Apis::BigtableadminV2::UpdateLogicalViewRequest
Request message for BigtableInstanceAdmin.UpdateLogicalView.
Corresponds to the JSON property originalRequest
5013 5014 5015 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 5013 def original_request @original_request end |
#request_time ⇒ String
The time at which the original request was received.
Corresponds to the JSON property requestTime
5018 5019 5020 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 5018 def request_time @request_time end |
#start_time ⇒ String
DEPRECATED: Use request_time instead.
Corresponds to the JSON property startTime
5023 5024 5025 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 5023 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5030 5031 5032 5033 5034 5035 5036 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 5030 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @finish_time = args[:finish_time] if args.key?(:finish_time) @original_request = args[:original_request] if args.key?(:original_request) @request_time = args[:request_time] if args.key?(:request_time) @start_time = args[:start_time] if args.key?(:start_time) end |