Class: Google::Apis::BigtableadminV2::UpdateLogicalViewRequest
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::UpdateLogicalViewRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
Request message for BigtableInstanceAdmin.UpdateLogicalView.
Instance Attribute Summary collapse
-
#logical_view ⇒ Google::Apis::BigtableadminV2::LogicalView
A SQL logical view object that can be referenced in SQL queries.
-
#update_mask ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpdateLogicalViewRequest
constructor
A new instance of UpdateLogicalViewRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpdateLogicalViewRequest
Returns a new instance of UpdateLogicalViewRequest.
5053 5054 5055 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 5053 def initialize(**args) update!(**args) end |
Instance Attribute Details
#logical_view ⇒ Google::Apis::BigtableadminV2::LogicalView
A SQL logical view object that can be referenced in SQL queries.
Corresponds to the JSON property logicalView
5046 5047 5048 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 5046 def logical_view @logical_view end |
#update_mask ⇒ String
Optional. The list of fields to update.
Corresponds to the JSON property updateMask
5051 5052 5053 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 5051 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5058 5059 5060 5061 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 5058 def update!(**args) @logical_view = args[:logical_view] if args.key?(:logical_view) @update_mask = args[:update_mask] if args.key?(:update_mask) end |