Class: Google::Apis::BigtableadminV2::AutomatedBackupPolicy
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::AutomatedBackupPolicy
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
Defines an automated backup policy for a table
Instance Attribute Summary collapse
-
#frequency ⇒ String
How frequently automated backups should occur.
-
#locations ⇒ Array<String>
Optional.
-
#retention_period ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AutomatedBackupPolicy
constructor
A new instance of AutomatedBackupPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AutomatedBackupPolicy
Returns a new instance of AutomatedBackupPolicy.
241 242 243 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 241 def initialize(**args) update!(**args) end |
Instance Attribute Details
#frequency ⇒ String
How frequently automated backups should occur. The only supported value at
this time is 24 hours. An undefined frequency is treated as 24 hours.
Corresponds to the JSON property frequency
225 226 227 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 225 def frequency @frequency end |
#locations ⇒ Array<String>
Optional. A list of Cloud Bigtable zones where automated backups are allowed
to be created. If empty, automated backups will be created in all zones of the
instance. Locations are in the format projects/project/locations/zone`.
This field can only set for tables in Enterprise Plus instances.
Corresponds to the JSON propertylocations`
233 234 235 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 233 def locations @locations end |
#retention_period ⇒ String
Required. How long the automated backups should be retained. Values must be at
least 3 days and at most 90 days.
Corresponds to the JSON property retentionPeriod
239 240 241 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 239 def retention_period @retention_period end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
246 247 248 249 250 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 246 def update!(**args) @frequency = args[:frequency] if args.key?(:frequency) @locations = args[:locations] if args.key?(:locations) @retention_period = args[:retention_period] if args.key?(:retention_period) end |