Class: Google::Apis::BigtableadminV2::CreateBackupMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

Metadata type for the operation returned by CreateBackup.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreateBackupMetadata

Returns a new instance of CreateBackupMetadata.



1051
1052
1053
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1051

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_timeString

If set, the time at which this operation finished or was cancelled. DEPRECATED: Use finish_time instead. Corresponds to the JSON property endTime

Returns:

  • (String)


1024
1025
1026
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1024

def end_time
  @end_time
end

#finish_timeString

The time at which the operation failed or was completed successfully. Corresponds to the JSON property finishTime

Returns:

  • (String)


1029
1030
1031
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1029

def finish_time
  @finish_time
end

#nameString

The name of the backup being created. Corresponds to the JSON property name

Returns:

  • (String)


1034
1035
1036
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1034

def name
  @name
end

#request_timeString

The time at which the original request was received. Corresponds to the JSON property requestTime

Returns:

  • (String)


1039
1040
1041
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1039

def request_time
  @request_time
end

#source_tableString

The name of the table the backup is created from. Corresponds to the JSON property sourceTable

Returns:

  • (String)


1044
1045
1046
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1044

def source_table
  @source_table
end

#start_timeString

The time at which this operation started. DEPRECATED: Use request_time instead. Corresponds to the JSON property startTime

Returns:

  • (String)


1049
1050
1051
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1049

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1056
1057
1058
1059
1060
1061
1062
1063
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1056

def update!(**args)
  @end_time = args[:end_time] if args.key?(:end_time)
  @finish_time = args[:finish_time] if args.key?(:finish_time)
  @name = args[:name] if args.key?(:name)
  @request_time = args[:request_time] if args.key?(:request_time)
  @source_table = args[:source_table] if args.key?(:source_table)
  @start_time = args[:start_time] if args.key?(:start_time)
end