Class: Google::Apis::BigtableadminV2::CreateInstanceRequest
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::CreateInstanceRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
Request message for BigtableInstanceAdmin.CreateInstance.
Instance Attribute Summary collapse
-
#clusters ⇒ Hash<String,Google::Apis::BigtableadminV2::Cluster>
Required.
-
#instance ⇒ Google::Apis::BigtableadminV2::Instance
A collection of Bigtable Tables and the resources that serve them.
-
#instance_id ⇒ String
Required.
-
#parent ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CreateInstanceRequest
constructor
A new instance of CreateInstanceRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CreateInstanceRequest
Returns a new instance of CreateInstanceRequest.
1215 1216 1217 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1215 def initialize(**args) update!(**args) end |
Instance Attribute Details
#clusters ⇒ Hash<String,Google::Apis::BigtableadminV2::Cluster>
Required. The clusters to be created within the instance, mapped by desired
cluster ID, e.g., just mycluster rather than projects/myproject/instances/
myinstance/clusters/mycluster. Fields marked OutputOnly must be left blank.
Corresponds to the JSON property clusters
1194 1195 1196 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1194 def clusters @clusters end |
#instance ⇒ Google::Apis::BigtableadminV2::Instance
A collection of Bigtable Tables and the resources that serve them. All tables
in an instance are served from all Clusters in the instance.
Corresponds to the JSON property instance
1200 1201 1202 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1200 def instance @instance end |
#instance_id ⇒ String
Required. The ID to be used when referring to the new instance within its
project, e.g., just myinstance rather than projects/myproject/instances/
myinstance.
Corresponds to the JSON property instanceId
1207 1208 1209 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1207 def instance_id @instance_id end |
#parent ⇒ String
Required. The unique name of the project in which to create the new instance.
Values are of the form projects/project`.
Corresponds to the JSON propertyparent`
1213 1214 1215 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1213 def parent @parent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1220 1221 1222 1223 1224 1225 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1220 def update!(**args) @clusters = args[:clusters] if args.key?(:clusters) @instance = args[:instance] if args.key?(:instance) @instance_id = args[:instance_id] if args.key?(:instance_id) @parent = args[:parent] if args.key?(:parent) end |