Class: Google::Apis::BigtableadminV2::CreateInstanceRequest
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::CreateInstanceRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
Request message for BigtableInstanceAdmin.CreateInstance.
Instance Attribute Summary collapse
-
#clusters ⇒ Hash<String,Google::Apis::BigtableadminV2::Cluster>
Required.
-
#instance ⇒ Google::Apis::BigtableadminV2::Instance
A collection of Bigtable Tables and the resources that serve them.
-
#instance_id ⇒ String
Required.
-
#parent ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CreateInstanceRequest
constructor
A new instance of CreateInstanceRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CreateInstanceRequest
Returns a new instance of CreateInstanceRequest.
1203 1204 1205 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1203 def initialize(**args) update!(**args) end |
Instance Attribute Details
#clusters ⇒ Hash<String,Google::Apis::BigtableadminV2::Cluster>
Required. The clusters to be created within the instance, mapped by desired
cluster ID, e.g., just mycluster rather than projects/myproject/instances/
myinstance/clusters/mycluster. Fields marked OutputOnly must be left blank.
Corresponds to the JSON property clusters
1182 1183 1184 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1182 def clusters @clusters end |
#instance ⇒ Google::Apis::BigtableadminV2::Instance
A collection of Bigtable Tables and the resources that serve them. All tables
in an instance are served from all Clusters in the instance.
Corresponds to the JSON property instance
1188 1189 1190 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1188 def instance @instance end |
#instance_id ⇒ String
Required. The ID to be used when referring to the new instance within its
project, e.g., just myinstance rather than projects/myproject/instances/
myinstance.
Corresponds to the JSON property instanceId
1195 1196 1197 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1195 def instance_id @instance_id end |
#parent ⇒ String
Required. The unique name of the project in which to create the new instance.
Values are of the form projects/project`.
Corresponds to the JSON propertyparent`
1201 1202 1203 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1201 def parent @parent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1208 1209 1210 1211 1212 1213 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1208 def update!(**args) @clusters = args[:clusters] if args.key?(:clusters) @instance = args[:instance] if args.key?(:instance) @instance_id = args[:instance_id] if args.key?(:instance_id) @parent = args[:parent] if args.key?(:parent) end |