Class: Google::Apis::BigtableadminV2::CreateLogicalViewMetadata
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::CreateLogicalViewMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
The metadata for the Operation returned by CreateLogicalView.
Instance Attribute Summary collapse
-
#end_time ⇒ String
DEPRECATED: Use finish_time instead.
-
#finish_time ⇒ String
The time at which the operation failed or was completed successfully.
-
#original_request ⇒ Google::Apis::BigtableadminV2::CreateLogicalViewRequest
Request message for BigtableInstanceAdmin.CreateLogicalView.
-
#request_time ⇒ String
The time at which the original request was received.
-
#start_time ⇒ String
DEPRECATED: Use request_time instead.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CreateLogicalViewMetadata
constructor
A new instance of CreateLogicalViewMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CreateLogicalViewMetadata
Returns a new instance of CreateLogicalViewMetadata.
1236 1237 1238 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1236 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
DEPRECATED: Use finish_time instead.
Corresponds to the JSON property endTime
1214 1215 1216 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1214 def end_time @end_time end |
#finish_time ⇒ String
The time at which the operation failed or was completed successfully.
Corresponds to the JSON property finishTime
1219 1220 1221 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1219 def finish_time @finish_time end |
#original_request ⇒ Google::Apis::BigtableadminV2::CreateLogicalViewRequest
Request message for BigtableInstanceAdmin.CreateLogicalView.
Corresponds to the JSON property originalRequest
1224 1225 1226 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1224 def original_request @original_request end |
#request_time ⇒ String
The time at which the original request was received.
Corresponds to the JSON property requestTime
1229 1230 1231 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1229 def request_time @request_time end |
#start_time ⇒ String
DEPRECATED: Use request_time instead.
Corresponds to the JSON property startTime
1234 1235 1236 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1234 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1241 1242 1243 1244 1245 1246 1247 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1241 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @finish_time = args[:finish_time] if args.key?(:finish_time) @original_request = args[:original_request] if args.key?(:original_request) @request_time = args[:request_time] if args.key?(:request_time) @start_time = args[:start_time] if args.key?(:start_time) end |