Class: Google::Apis::BigtableadminV2::CreateLogicalViewRequest
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::CreateLogicalViewRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
Request message for BigtableInstanceAdmin.CreateLogicalView.
Instance Attribute Summary collapse
-
#logical_view ⇒ Google::Apis::BigtableadminV2::LogicalView
A SQL logical view object that can be referenced in SQL queries.
-
#logical_view_id ⇒ String
Required.
-
#parent ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CreateLogicalViewRequest
constructor
A new instance of CreateLogicalViewRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CreateLogicalViewRequest
Returns a new instance of CreateLogicalViewRequest.
1280 1281 1282 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1280 def initialize(**args) update!(**args) end |
Instance Attribute Details
#logical_view ⇒ Google::Apis::BigtableadminV2::LogicalView
A SQL logical view object that can be referenced in SQL queries.
Corresponds to the JSON property logicalView
1266 1267 1268 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1266 def logical_view @logical_view end |
#logical_view_id ⇒ String
Required. The ID to use for the logical view, which will become the final
component of the logical view's resource name.
Corresponds to the JSON property logicalViewId
1272 1273 1274 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1272 def logical_view_id @logical_view_id end |
#parent ⇒ String
Required. The parent instance where this logical view will be created. Format:
projects/project/instances/instance`.
Corresponds to the JSON propertyparent`
1278 1279 1280 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1278 def parent @parent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1285 1286 1287 1288 1289 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1285 def update!(**args) @logical_view = args[:logical_view] if args.key?(:logical_view) @logical_view_id = args[:logical_view_id] if args.key?(:logical_view_id) @parent = args[:parent] if args.key?(:parent) end |