Class: Google::Apis::BigtableadminV2::CreateLogicalViewRequest
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::CreateLogicalViewRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
Request message for BigtableInstanceAdmin.CreateLogicalView.
Instance Attribute Summary collapse
-
#logical_view ⇒ Google::Apis::BigtableadminV2::LogicalView
A SQL logical view object that can be referenced in SQL queries.
-
#logical_view_id ⇒ String
Required.
-
#parent ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CreateLogicalViewRequest
constructor
A new instance of CreateLogicalViewRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CreateLogicalViewRequest
Returns a new instance of CreateLogicalViewRequest.
1271 1272 1273 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1271 def initialize(**args) update!(**args) end |
Instance Attribute Details
#logical_view ⇒ Google::Apis::BigtableadminV2::LogicalView
A SQL logical view object that can be referenced in SQL queries.
Corresponds to the JSON property logicalView
1257 1258 1259 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1257 def logical_view @logical_view end |
#logical_view_id ⇒ String
Required. The ID to use for the logical view, which will become the final
component of the logical view's resource name.
Corresponds to the JSON property logicalViewId
1263 1264 1265 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1263 def logical_view_id @logical_view_id end |
#parent ⇒ String
Required. The parent instance where this logical view will be created. Format:
projects/project/instances/instance`.
Corresponds to the JSON propertyparent`
1269 1270 1271 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1269 def parent @parent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1276 1277 1278 1279 1280 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1276 def update!(**args) @logical_view = args[:logical_view] if args.key?(:logical_view) @logical_view_id = args[:logical_view_id] if args.key?(:logical_view_id) @parent = args[:parent] if args.key?(:parent) end |