Class: Google::Apis::BigtableadminV2::CreateMaterializedViewMetadata
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::CreateMaterializedViewMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
The metadata for the Operation returned by CreateMaterializedView.
Instance Attribute Summary collapse
-
#end_time ⇒ String
If set, the time at which this operation finished or was canceled.
-
#finish_time ⇒ String
The time at which the operation failed or was completed successfully.
-
#original_request ⇒ Google::Apis::BigtableadminV2::CreateMaterializedViewRequest
Request message for BigtableInstanceAdmin.CreateMaterializedView.
-
#request_time ⇒ String
The time at which the original request was received.
-
#start_time ⇒ String
The time at which this operation started.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CreateMaterializedViewMetadata
constructor
A new instance of CreateMaterializedViewMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CreateMaterializedViewMetadata
Returns a new instance of CreateMaterializedViewMetadata.
1313 1314 1315 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1313 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
If set, the time at which this operation finished or was canceled. DEPRECATED:
Use finish_time instead.
Corresponds to the JSON property endTime
1291 1292 1293 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1291 def end_time @end_time end |
#finish_time ⇒ String
The time at which the operation failed or was completed successfully.
Corresponds to the JSON property finishTime
1296 1297 1298 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1296 def finish_time @finish_time end |
#original_request ⇒ Google::Apis::BigtableadminV2::CreateMaterializedViewRequest
Request message for BigtableInstanceAdmin.CreateMaterializedView.
Corresponds to the JSON property originalRequest
1301 1302 1303 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1301 def original_request @original_request end |
#request_time ⇒ String
The time at which the original request was received.
Corresponds to the JSON property requestTime
1306 1307 1308 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1306 def request_time @request_time end |
#start_time ⇒ String
The time at which this operation started. DEPRECATED: Use request_time instead.
Corresponds to the JSON property startTime
1311 1312 1313 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1311 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1318 1319 1320 1321 1322 1323 1324 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1318 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @finish_time = args[:finish_time] if args.key?(:finish_time) @original_request = args[:original_request] if args.key?(:original_request) @request_time = args[:request_time] if args.key?(:request_time) @start_time = args[:start_time] if args.key?(:start_time) end |