Class: Google::Apis::BigtableadminV2::CreateMaterializedViewRequest
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::CreateMaterializedViewRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
Request message for BigtableInstanceAdmin.CreateMaterializedView.
Instance Attribute Summary collapse
-
#ignore_warnings ⇒ Boolean
(also: #ignore_warnings?)
Optional.
-
#materialized_view ⇒ Google::Apis::BigtableadminV2::MaterializedView
A materialized view object that can be referenced in SQL queries.
-
#materialized_view_id ⇒ String
Required.
-
#parent ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CreateMaterializedViewRequest
constructor
A new instance of CreateMaterializedViewRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CreateMaterializedViewRequest
Returns a new instance of CreateMaterializedViewRequest.
1376 1377 1378 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1376 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ignore_warnings ⇒ Boolean Also known as: ignore_warnings?
Optional. If true, ignore optional safety checks when creating the
materialized view.
Corresponds to the JSON property ignoreWarnings
1356 1357 1358 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1356 def ignore_warnings @ignore_warnings end |
#materialized_view ⇒ Google::Apis::BigtableadminV2::MaterializedView
A materialized view object that can be referenced in SQL queries.
Corresponds to the JSON property materializedView
1362 1363 1364 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1362 def materialized_view @materialized_view end |
#materialized_view_id ⇒ String
Required. The ID to use for the materialized view, which will become the final
component of the materialized view's resource name.
Corresponds to the JSON property materializedViewId
1368 1369 1370 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1368 def materialized_view_id @materialized_view_id end |
#parent ⇒ String
Required. The parent instance where this materialized view will be created.
Format: projects/project/instances/instance`.
Corresponds to the JSON propertyparent`
1374 1375 1376 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1374 def parent @parent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1381 1382 1383 1384 1385 1386 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1381 def update!(**args) @ignore_warnings = args[:ignore_warnings] if args.key?(:ignore_warnings) @materialized_view = args[:materialized_view] if args.key?(:materialized_view) @materialized_view_id = args[:materialized_view_id] if args.key?(:materialized_view_id) @parent = args[:parent] if args.key?(:parent) end |