Class: Google::Apis::BigtableadminV2::CreateMaterializedViewRequest
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::CreateMaterializedViewRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
Request message for BigtableInstanceAdmin.CreateMaterializedView.
Instance Attribute Summary collapse
-
#materialized_view ⇒ Google::Apis::BigtableadminV2::MaterializedView
A materialized view object that can be referenced in SQL queries.
-
#materialized_view_id ⇒ String
Required.
-
#parent ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CreateMaterializedViewRequest
constructor
A new instance of CreateMaterializedViewRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CreateMaterializedViewRequest
Returns a new instance of CreateMaterializedViewRequest.
1357 1358 1359 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1357 def initialize(**args) update!(**args) end |
Instance Attribute Details
#materialized_view ⇒ Google::Apis::BigtableadminV2::MaterializedView
A materialized view object that can be referenced in SQL queries.
Corresponds to the JSON property materializedView
1343 1344 1345 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1343 def materialized_view @materialized_view end |
#materialized_view_id ⇒ String
Required. The ID to use for the materialized view, which will become the final
component of the materialized view's resource name.
Corresponds to the JSON property materializedViewId
1349 1350 1351 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1349 def materialized_view_id @materialized_view_id end |
#parent ⇒ String
Required. The parent instance where this materialized view will be created.
Format: projects/project/instances/instance`.
Corresponds to the JSON propertyparent`
1355 1356 1357 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1355 def parent @parent end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1362 1363 1364 1365 1366 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1362 def update!(**args) @materialized_view = args[:materialized_view] if args.key?(:materialized_view) @materialized_view_id = args[:materialized_view_id] if args.key?(:materialized_view_id) @parent = args[:parent] if args.key?(:parent) end |