Class: Google::Apis::BigtableadminV2::CreateMaterializedViewRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

Request message for BigtableInstanceAdmin.CreateMaterializedView.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreateMaterializedViewRequest

Returns a new instance of CreateMaterializedViewRequest.



1348
1349
1350
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1348

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#materialized_viewGoogle::Apis::BigtableadminV2::MaterializedView

A materialized view object that can be referenced in SQL queries. Corresponds to the JSON property materializedView



1334
1335
1336
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1334

def materialized_view
  @materialized_view
end

#materialized_view_idString

Required. The ID to use for the materialized view, which will become the final component of the materialized view's resource name. Corresponds to the JSON property materializedViewId

Returns:

  • (String)


1340
1341
1342
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1340

def materialized_view_id
  @materialized_view_id
end

#parentString

Required. The parent instance where this materialized view will be created. Format: projects/project/instances/instance`. Corresponds to the JSON propertyparent`

Returns:

  • (String)


1346
1347
1348
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1346

def parent
  @parent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1353
1354
1355
1356
1357
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1353

def update!(**args)
  @materialized_view = args[:materialized_view] if args.key?(:materialized_view)
  @materialized_view_id = args[:materialized_view_id] if args.key?(:materialized_view_id)
  @parent = args[:parent] if args.key?(:parent)
end