Class: Google::Apis::BigtableadminV2::CreateSchemaBundleMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

The metadata for the Operation returned by CreateSchemaBundle.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CreateSchemaBundleMetadata

Returns a new instance of CreateSchemaBundleMetadata.



1390
1391
1392
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1390

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#finish_timeString

The time at which the operation failed or was completed successfully. Corresponds to the JSON property finishTime

Returns:

  • (String)


1376
1377
1378
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1376

def finish_time
  @finish_time
end

#nameString

The unique name identifying this schema bundle. Values are of the form projects/project/instances/instance/tables/table/schemaBundles/ schema_bundle` Corresponds to the JSON propertyname`

Returns:

  • (String)


1383
1384
1385
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1383

def name
  @name
end

#request_timeString

The time at which the original request was received. Corresponds to the JSON property requestTime

Returns:

  • (String)


1388
1389
1390
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1388

def request_time
  @request_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1395
1396
1397
1398
1399
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1395

def update!(**args)
  @finish_time = args[:finish_time] if args.key?(:finish_time)
  @name = args[:name] if args.key?(:name)
  @request_time = args[:request_time] if args.key?(:request_time)
end