Class: Google::Apis::BigtableadminV2::CreateSchemaBundleMetadata
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::CreateSchemaBundleMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
The metadata for the Operation returned by CreateSchemaBundle.
Instance Attribute Summary collapse
-
#finish_time ⇒ String
The time at which the operation failed or was completed successfully.
-
#name ⇒ String
The unique name identifying this schema bundle.
-
#request_time ⇒ String
The time at which the original request was received.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CreateSchemaBundleMetadata
constructor
A new instance of CreateSchemaBundleMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CreateSchemaBundleMetadata
Returns a new instance of CreateSchemaBundleMetadata.
1381 1382 1383 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1381 def initialize(**args) update!(**args) end |
Instance Attribute Details
#finish_time ⇒ String
The time at which the operation failed or was completed successfully.
Corresponds to the JSON property finishTime
1367 1368 1369 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1367 def finish_time @finish_time end |
#name ⇒ String
The unique name identifying this schema bundle. Values are of the form
projects/project/instances/instance/tables/table/schemaBundles/
schema_bundle`
Corresponds to the JSON propertyname`
1374 1375 1376 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1374 def name @name end |
#request_time ⇒ String
The time at which the original request was received.
Corresponds to the JSON property requestTime
1379 1380 1381 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1379 def request_time @request_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1386 1387 1388 1389 1390 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1386 def update!(**args) @finish_time = args[:finish_time] if args.key?(:finish_time) @name = args[:name] if args.key?(:name) @request_time = args[:request_time] if args.key?(:request_time) end |