Class: Google::Apis::BigtableadminV2::EncryptionConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

Cloud Key Management Service (Cloud KMS) settings for a CMEK-protected cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EncryptionConfig

Returns a new instance of EncryptionConfig.



1539
1540
1541
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1539

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kms_key_nameString

Describes the Cloud KMS encryption key that will be used to protect the destination Bigtable cluster. The requirements for this key are: 1) The Cloud Bigtable service account associated with the project that contains this cluster must be granted the cloudkms.cryptoKeyEncrypterDecrypter role on the CMEK key. 2) Only regional keys can be used and the region of the CMEK key must match the region of the cluster. Values are of the form projects/ project/locations/location/keyRings/keyring/cryptoKeys/key` Corresponds to the JSON propertykmsKeyName`

Returns:

  • (String)


1537
1538
1539
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1537

def kms_key_name
  @kms_key_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1544
1545
1546
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1544

def update!(**args)
  @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name)
end