Class: Google::Apis::BigtableadminV2::EncryptionInfo
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::EncryptionInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
Encryption information for a given resource. If this resource is protected with customer managed encryption, the in-use Cloud Key Management Service ( Cloud KMS) key version is specified along with its status.
Instance Attribute Summary collapse
-
#encryption_status ⇒ Google::Apis::BigtableadminV2::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#encryption_type ⇒ String
Output only.
-
#kms_key_version ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EncryptionInfo
constructor
A new instance of EncryptionInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EncryptionInfo
Returns a new instance of EncryptionInfo.
1567 1568 1569 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1567 def initialize(**args) update!(**args) end |
Instance Attribute Details
#encryption_status ⇒ Google::Apis::BigtableadminV2::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property encryptionStatus
1554 1555 1556 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1554 def encryption_status @encryption_status end |
#encryption_type ⇒ String
Output only. The type of encryption used to protect this resource.
Corresponds to the JSON property encryptionType
1559 1560 1561 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1559 def encryption_type @encryption_type end |
#kms_key_version ⇒ String
Output only. The version of the Cloud KMS key specified in the parent cluster
that is in use for the data underlying this table.
Corresponds to the JSON property kmsKeyVersion
1565 1566 1567 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1565 def kms_key_version @kms_key_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1572 1573 1574 1575 1576 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1572 def update!(**args) @encryption_status = args[:encryption_status] if args.key?(:encryption_status) @encryption_type = args[:encryption_type] if args.key?(:encryption_type) @kms_key_version = args[:kms_key_version] if args.key?(:kms_key_version) end |