Class: Google::Apis::BigtableadminV2::GoogleBigtableAdminV2AuthorizedViewFamilySubsets
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::GoogleBigtableAdminV2AuthorizedViewFamilySubsets
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
Subsets of a column family that are included in this AuthorizedView.
Instance Attribute Summary collapse
-
#qualifier_prefixes ⇒ Array<String>
Prefixes for qualifiers to be included in the AuthorizedView.
-
#qualifiers ⇒ Array<String>
Individual exact column qualifiers to be included in the AuthorizedView.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleBigtableAdminV2AuthorizedViewFamilySubsets
constructor
A new instance of GoogleBigtableAdminV2AuthorizedViewFamilySubsets.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleBigtableAdminV2AuthorizedViewFamilySubsets
Returns a new instance of GoogleBigtableAdminV2AuthorizedViewFamilySubsets.
1777 1778 1779 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1777 def initialize(**args) update!(**args) end |
Instance Attribute Details
#qualifier_prefixes ⇒ Array<String>
Prefixes for qualifiers to be included in the AuthorizedView. Every qualifier
starting with one of these prefixes is included in the AuthorizedView. To
provide access to all qualifiers, include the empty string as a prefix ("").
Corresponds to the JSON property qualifierPrefixes
1770 1771 1772 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1770 def qualifier_prefixes @qualifier_prefixes end |
#qualifiers ⇒ Array<String>
Individual exact column qualifiers to be included in the AuthorizedView.
Corresponds to the JSON property qualifiers
1775 1776 1777 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1775 def qualifiers @qualifiers end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1782 1783 1784 1785 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1782 def update!(**args) @qualifier_prefixes = args[:qualifier_prefixes] if args.key?(:qualifier_prefixes) @qualifiers = args[:qualifiers] if args.key?(:qualifiers) end |