Class: Google::Apis::BigtableadminV2::GoogleBigtableAdminV2TypeAggregate

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

A value that combines incremental updates into a summarized value. Data is never directly written or read using type Aggregate. Writes provide either the input_type or state_type, and reads always return the state_type .

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleBigtableAdminV2TypeAggregate

Returns a new instance of GoogleBigtableAdminV2TypeAggregate.



1898
1899
1900
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1898

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hllpp_unique_countGoogle::Apis::BigtableadminV2::GoogleBigtableAdminV2TypeAggregateHyperLogLogPlusPlusUniqueCount

Computes an approximate unique count over the input values. When using raw data as input, be careful to use a consistent encoding. Otherwise the same value encoded differently could count more than once, or two distinct values could count as identical. Input: Any, or omit for Raw State: TBD Special state conversions: Int64 (the unique count estimate) Corresponds to the JSON property hllppUniqueCount



1838
1839
1840
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1838

def hllpp_unique_count
  @hllpp_unique_count
end

#input_typeGoogle::Apis::BigtableadminV2::Type

Type represents the type of data that is written to, read from, or stored in Bigtable. It is heavily based on the GoogleSQL standard to help maintain familiarity and consistency across products and features. For compatibility with Bigtable's existing untyped APIs, each Type includes an Encoding which describes how to convert to or from the underlying data. Each encoding can operate in one of two modes: - Sorted: In this mode, Bigtable guarantees that Encode(X) <= Encode(Y) if and only if X <= Y. This is useful anywhere sort order is important, for example when encoding keys. - Distinct: In this mode, Bigtable guarantees that if X != Y then Encode(X) != Encode(Y). However, the converse is not guaranteed. For example, both 'foo': '1', 'bar': '2' and 'bar': '2', 'foo': '1' are valid encodings of the same JSON value. The API clearly documents which mode is used wherever an encoding can be configured. Each encoding also documents which values are supported in which modes. For example, when encoding INT64 as a numeric STRING, negative numbers cannot be encoded in sorted mode. This is because INT64(1) > INT64(-1) , but STRING("-00001") > STRING("00001"). Corresponds to the JSON property inputType



1858
1859
1860
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1858

def input_type
  @input_type
end

#maxGoogle::Apis::BigtableadminV2::GoogleBigtableAdminV2TypeAggregateMax

Computes the max of the input values. Allowed input: Int64 State: same as input Corresponds to the JSON property max



1864
1865
1866
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1864

def max
  @max
end

#minGoogle::Apis::BigtableadminV2::GoogleBigtableAdminV2TypeAggregateMin

Computes the min of the input values. Allowed input: Int64 State: same as input Corresponds to the JSON property min



1870
1871
1872
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1870

def min
  @min
end

#state_typeGoogle::Apis::BigtableadminV2::Type

Type represents the type of data that is written to, read from, or stored in Bigtable. It is heavily based on the GoogleSQL standard to help maintain familiarity and consistency across products and features. For compatibility with Bigtable's existing untyped APIs, each Type includes an Encoding which describes how to convert to or from the underlying data. Each encoding can operate in one of two modes: - Sorted: In this mode, Bigtable guarantees that Encode(X) <= Encode(Y) if and only if X <= Y. This is useful anywhere sort order is important, for example when encoding keys. - Distinct: In this mode, Bigtable guarantees that if X != Y then Encode(X) != Encode(Y). However, the converse is not guaranteed. For example, both 'foo': '1', 'bar': '2' and 'bar': '2', 'foo': '1' are valid encodings of the same JSON value. The API clearly documents which mode is used wherever an encoding can be configured. Each encoding also documents which values are supported in which modes. For example, when encoding INT64 as a numeric STRING, negative numbers cannot be encoded in sorted mode. This is because INT64(1) > INT64(-1) , but STRING("-00001") > STRING("00001"). Corresponds to the JSON property stateType



1890
1891
1892
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1890

def state_type
  @state_type
end

#sumGoogle::Apis::BigtableadminV2::GoogleBigtableAdminV2TypeAggregateSum

Computes the sum of the input values. Allowed input: Int64 State: same as input Corresponds to the JSON property sum



1896
1897
1898
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1896

def sum
  @sum
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1903
1904
1905
1906
1907
1908
1909
1910
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 1903

def update!(**args)
  @hllpp_unique_count = args[:hllpp_unique_count] if args.key?(:hllpp_unique_count)
  @input_type = args[:input_type] if args.key?(:input_type)
  @max = args[:max] if args.key?(:max)
  @min = args[:min] if args.key?(:min)
  @state_type = args[:state_type] if args.key?(:state_type)
  @sum = args[:sum] if args.key?(:sum)
end