Class: Google::Apis::BigtableadminV2::GoogleBigtableAdminV2TypeArray

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

An ordered list of elements of a given type. Values of type Array are stored in Value.array_value.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleBigtableAdminV2TypeArray

Returns a new instance of GoogleBigtableAdminV2TypeArray.



2025
2026
2027
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2025

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#element_typeGoogle::Apis::BigtableadminV2::Type

Type represents the type of data that is written to, read from, or stored in Bigtable. It is heavily based on the GoogleSQL standard to help maintain familiarity and consistency across products and features. For compatibility with Bigtable's existing untyped APIs, each Type includes an Encoding which describes how to convert to or from the underlying data. Each encoding can operate in one of two modes: - Sorted: In this mode, Bigtable guarantees that Encode(X) <= Encode(Y) if and only if X <= Y. This is useful anywhere sort order is important, for example when encoding keys. - Distinct: In this mode, Bigtable guarantees that if X != Y then Encode(X) != Encode(Y). However, the converse is not guaranteed. For example, both 'foo': '1', 'bar': '2' and 'bar': '2', 'foo': '1' are valid encodings of the same JSON value. The API clearly documents which mode is used wherever an encoding can be configured. Each encoding also documents which values are supported in which modes. For example, when encoding INT64 as a numeric STRING, negative numbers cannot be encoded in sorted mode. This is because INT64(1) > INT64(-1) , but STRING("-00001") > STRING("00001"). Corresponds to the JSON property elementType



2023
2024
2025
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2023

def element_type
  @element_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2030
2031
2032
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2030

def update!(**args)
  @element_type = args[:element_type] if args.key?(:element_type)
end