Class: Google::Apis::BigtableadminV2::GoogleBigtableAdminV2TypeBytes

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

Bytes Values of type Bytes are stored in Value.bytes_value.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleBigtableAdminV2TypeBytes

Returns a new instance of GoogleBigtableAdminV2TypeBytes.



2029
2030
2031
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2029

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#encodingGoogle::Apis::BigtableadminV2::GoogleBigtableAdminV2TypeBytesEncoding

Rules used to convert to or from lower level types. Corresponds to the JSON property encoding



2027
2028
2029
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2027

def encoding
  @encoding
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2034
2035
2036
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2034

def update!(**args)
  @encoding = args[:encoding] if args.key?(:encoding)
end