Class: Google::Apis::BigtableadminV2::GoogleBigtableAdminV2TypeBytesEncodingRaw
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::GoogleBigtableAdminV2TypeBytesEncodingRaw
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
Leaves the value as-is. Sorted mode: all values are supported. Distinct mode: all values are supported.
Instance Attribute Summary collapse
-
#escape_nulls ⇒ Boolean
(also: #escape_nulls?)
If set, allows NULL values to be encoded as the empty string "".
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleBigtableAdminV2TypeBytesEncodingRaw
constructor
A new instance of GoogleBigtableAdminV2TypeBytesEncodingRaw.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleBigtableAdminV2TypeBytesEncodingRaw
Returns a new instance of GoogleBigtableAdminV2TypeBytesEncodingRaw.
2139 2140 2141 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2139 def initialize(**args) update!(**args) end |
Instance Attribute Details
#escape_nulls ⇒ Boolean Also known as: escape_nulls?
If set, allows NULL values to be encoded as the empty string "". The actual
empty string, or any value which only contains the null byte 0x00, has one
more null byte appended.
Corresponds to the JSON property escapeNulls
2136 2137 2138 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2136 def escape_nulls @escape_nulls end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2144 2145 2146 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2144 def update!(**args) @escape_nulls = args[:escape_nulls] if args.key?(:escape_nulls) end |