Class: Google::Apis::BigtableadminV2::GoogleBigtableAdminV2TypeBytesEncodingRaw

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

Leaves the value as-is. Sorted mode: all values are supported. Distinct mode: all values are supported.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleBigtableAdminV2TypeBytesEncodingRaw

Returns a new instance of GoogleBigtableAdminV2TypeBytesEncodingRaw.



2119
2120
2121
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2119

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#escape_nullsBoolean Also known as: escape_nulls?

If set, allows NULL values to be encoded as the empty string "". The actual empty string, or any value which only contains the null byte 0x00, has one more null byte appended. Corresponds to the JSON property escapeNulls

Returns:

  • (Boolean)


2116
2117
2118
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2116

def escape_nulls
  @escape_nulls
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2124
2125
2126
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2124

def update!(**args)
  @escape_nulls = args[:escape_nulls] if args.key?(:escape_nulls)
end