Class: Google::Apis::BigtableadminV2::GoogleBigtableAdminV2TypeBytesEncodingRaw
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::GoogleBigtableAdminV2TypeBytesEncodingRaw
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
Leaves the value as-is. Sorted mode: all values are supported. Distinct mode: all values are supported.
Instance Attribute Summary collapse
-
#escape_nulls ⇒ Boolean
(also: #escape_nulls?)
If set, allows NULL values to be encoded as the empty string "".
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleBigtableAdminV2TypeBytesEncodingRaw
constructor
A new instance of GoogleBigtableAdminV2TypeBytesEncodingRaw.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleBigtableAdminV2TypeBytesEncodingRaw
Returns a new instance of GoogleBigtableAdminV2TypeBytesEncodingRaw.
2072 2073 2074 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2072 def initialize(**args) update!(**args) end |
Instance Attribute Details
#escape_nulls ⇒ Boolean Also known as: escape_nulls?
If set, allows NULL values to be encoded as the empty string "". The actual
empty string, or any value which only contains the null byte 0x00, has one
more null byte appended.
Corresponds to the JSON property escapeNulls
2069 2070 2071 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2069 def escape_nulls @escape_nulls end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2077 2078 2079 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2077 def update!(**args) @escape_nulls = args[:escape_nulls] if args.key?(:escape_nulls) end |