Class: Google::Apis::BigtableadminV2::GoogleBigtableAdminV2TypeEnum
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::GoogleBigtableAdminV2TypeEnum
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
A protobuf enum type. Values of type Enum are stored in Value.int_value.
Instance Attribute Summary collapse
-
#enum_name ⇒ String
The fully qualified name of the protobuf enum message, including package.
-
#schema_bundle_id ⇒ String
The ID of the schema bundle that this enum is defined in.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleBigtableAdminV2TypeEnum
constructor
A new instance of GoogleBigtableAdminV2TypeEnum.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleBigtableAdminV2TypeEnum
Returns a new instance of GoogleBigtableAdminV2TypeEnum.
2157 2158 2159 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2157 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enum_name ⇒ String
The fully qualified name of the protobuf enum message, including package. In
the format of "foo.bar.EnumMessage".
Corresponds to the JSON property enumName
2150 2151 2152 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2150 def enum_name @enum_name end |
#schema_bundle_id ⇒ String
The ID of the schema bundle that this enum is defined in.
Corresponds to the JSON property schemaBundleId
2155 2156 2157 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2155 def schema_bundle_id @schema_bundle_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2162 2163 2164 2165 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2162 def update!(**args) @enum_name = args[:enum_name] if args.key?(:enum_name) @schema_bundle_id = args[:schema_bundle_id] if args.key?(:schema_bundle_id) end |