Class: Google::Apis::BigtableadminV2::GoogleBigtableAdminV2TypeEnum
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::GoogleBigtableAdminV2TypeEnum
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
A protobuf enum type. Values of type Enum are stored in Value.int_value.
Instance Attribute Summary collapse
-
#enum_name ⇒ String
The fully qualified name of the protobuf enum message, including package.
-
#schema_bundle_id ⇒ String
The ID of the schema bundle that this enum is defined in.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleBigtableAdminV2TypeEnum
constructor
A new instance of GoogleBigtableAdminV2TypeEnum.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleBigtableAdminV2TypeEnum
Returns a new instance of GoogleBigtableAdminV2TypeEnum.
2110 2111 2112 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2110 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enum_name ⇒ String
The fully qualified name of the protobuf enum message, including package. In
the format of "foo.bar.EnumMessage".
Corresponds to the JSON property enumName
2103 2104 2105 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2103 def enum_name @enum_name end |
#schema_bundle_id ⇒ String
The ID of the schema bundle that this enum is defined in.
Corresponds to the JSON property schemaBundleId
2108 2109 2110 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2108 def schema_bundle_id @schema_bundle_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2115 2116 2117 2118 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2115 def update!(**args) @enum_name = args[:enum_name] if args.key?(:enum_name) @schema_bundle_id = args[:schema_bundle_id] if args.key?(:schema_bundle_id) end |