Class: Google::Apis::BigtableadminV2::GoogleBigtableAdminV2TypeProto
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::GoogleBigtableAdminV2TypeProto
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
A protobuf message type. Values of type Proto are stored in Value.
bytes_value.
Instance Attribute Summary collapse
-
#message_name ⇒ String
The fully qualified name of the protobuf message, including package.
-
#schema_bundle_id ⇒ String
The ID of the schema bundle that this proto is defined in.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleBigtableAdminV2TypeProto
constructor
A new instance of GoogleBigtableAdminV2TypeProto.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleBigtableAdminV2TypeProto
Returns a new instance of GoogleBigtableAdminV2TypeProto.
2323 2324 2325 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2323 def initialize(**args) update!(**args) end |
Instance Attribute Details
#message_name ⇒ String
The fully qualified name of the protobuf message, including package. In the
format of "foo.bar.Message".
Corresponds to the JSON property messageName
2316 2317 2318 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2316 def @message_name end |
#schema_bundle_id ⇒ String
The ID of the schema bundle that this proto is defined in.
Corresponds to the JSON property schemaBundleId
2321 2322 2323 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2321 def schema_bundle_id @schema_bundle_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2328 2329 2330 2331 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2328 def update!(**args) @message_name = args[:message_name] if args.key?(:message_name) @schema_bundle_id = args[:schema_bundle_id] if args.key?(:schema_bundle_id) end |