Class: Google::Apis::BigtableadminV2::GoogleBigtableAdminV2TypeTimestampEncoding
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::GoogleBigtableAdminV2TypeTimestampEncoding
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
Rules used to convert to or from lower level types.
Instance Attribute Summary collapse
-
#unix_micros_int64 ⇒ Google::Apis::BigtableadminV2::GoogleBigtableAdminV2TypeInt64Encoding
Rules used to convert to or from lower level types.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleBigtableAdminV2TypeTimestampEncoding
constructor
A new instance of GoogleBigtableAdminV2TypeTimestampEncoding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleBigtableAdminV2TypeTimestampEncoding
Returns a new instance of GoogleBigtableAdminV2TypeTimestampEncoding.
2647 2648 2649 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2647 def initialize(**args) update!(**args) end |
Instance Attribute Details
#unix_micros_int64 ⇒ Google::Apis::BigtableadminV2::GoogleBigtableAdminV2TypeInt64Encoding
Rules used to convert to or from lower level types.
Corresponds to the JSON property unixMicrosInt64
2645 2646 2647 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2645 def unix_micros_int64 @unix_micros_int64 end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2652 2653 2654 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2652 def update!(**args) @unix_micros_int64 = args[:unix_micros_int64] if args.key?(:unix_micros_int64) end |