Class: Google::Apis::BigtableadminV2::Instance

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

A collection of Bigtable Tables and the resources that serve them. All tables in an instance are served from all Clusters in the instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Instance

Returns a new instance of Instance.



2940
2941
2942
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2940

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. A commit timestamp representing when this Instance was created. For instances created before this field was added (August 2021), this value is seconds: 0, nanos: 1. Corresponds to the JSON property createTime

Returns:

  • (String)


2871
2872
2873
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2871

def create_time
  @create_time
end

#display_nameString

Required. The descriptive name for this instance as it appears in UIs. Can be changed at any time, but should be kept globally unique to avoid confusion. Corresponds to the JSON property displayName

Returns:

  • (String)


2877
2878
2879
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2877

def display_name
  @display_name
end

#editionString

Optional. The edition of the instance. See Edition for details. Corresponds to the JSON property edition

Returns:

  • (String)


2882
2883
2884
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2882

def edition
  @edition
end

#knowledge_catalog_regionString

Output only. The region where Knowledge Catalog data is synced to and stored, including user-created aspects. Corresponds to the JSON property knowledgeCatalogRegion

Returns:

  • (String)


2888
2889
2890
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2888

def knowledge_catalog_region
  @knowledge_catalog_region
end

#labelsHash<String,String>

Labels are a flexible and lightweight mechanism for organizing cloud resources into groups that reflect a customer's organizational needs and deployment strategies. They can be used to filter resources and aggregate metrics. * Label keys must be between 1 and 63 characters long and must conform to the regular expression: \pLl\pLo0,62. * Label values must be between 0 and 63 characters long and must conform to the regular expression: [\pLl\pLo\ pN_-]0,63`. * No more than 64 labels can be associated with a given resource. * Keys and values must both be under 128 bytes. Corresponds to the JSON propertylabels`

Returns:

  • (Hash<String,String>)


2900
2901
2902
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2900

def labels
  @labels
end

#nameString

The unique name of the instance. Values are of the form projects/project/ instances/a-z+[a-z0-9]. Corresponds to the JSON property name

Returns:

  • (String)


2906
2907
2908
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2906

def name
  @name
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


2911
2912
2913
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2911

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


2917
2918
2919
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2917

def satisfies_pzs
  @satisfies_pzs
end

#stateString

Output only. The current state of the instance. Corresponds to the JSON property state

Returns:

  • (String)


2923
2924
2925
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2923

def state
  @state
end

#tagsHash<String,String>

Optional. Input only. Immutable. Tag keys/values directly bound to this resource. For example: - "123/environment": "production", - "123/costCenter": " marketing" Tags and Labels (above) are both used to bind metadata to resources, with different use-cases. See https://cloud.google.com/resource-manager/docs/ tags/tags-overview for an in-depth overview on the difference between tags and labels. Corresponds to the JSON property tags

Returns:

  • (Hash<String,String>)


2933
2934
2935
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2933

def tags
  @tags
end

#typeString

The type of the instance. Defaults to PRODUCTION. Corresponds to the JSON property type

Returns:

  • (String)


2938
2939
2940
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2938

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2945
2946
2947
2948
2949
2950
2951
2952
2953
2954
2955
2956
2957
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2945

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @edition = args[:edition] if args.key?(:edition)
  @knowledge_catalog_region = args[:knowledge_catalog_region] if args.key?(:knowledge_catalog_region)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @state = args[:state] if args.key?(:state)
  @tags = args[:tags] if args.key?(:tags)
  @type = args[:type] if args.key?(:type)
end