Class: Google::Apis::BigtableadminV2::Instance
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::Instance
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
A collection of Bigtable Tables and the resources that serve them. All tables in an instance are served from all Clusters in the instance.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Required.
-
#edition ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Labels are a flexible and lightweight mechanism for organizing cloud resources into groups that reflect a customer's organizational needs and deployment strategies.
-
#name ⇒ String
The unique name of the instance.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#state ⇒ String
Output only.
-
#tags ⇒ Hash<String,String>
Optional.
-
#type ⇒ String
The type of the instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Instance
constructor
A new instance of Instance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Instance
Returns a new instance of Instance.
2934 2935 2936 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2934 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. A commit timestamp representing when this Instance was created.
For instances created before this field was added (August 2021), this value is
seconds: 0, nanos: 1.
Corresponds to the JSON property createTime
2871 2872 2873 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2871 def create_time @create_time end |
#display_name ⇒ String
Required. The descriptive name for this instance as it appears in UIs. Can be
changed at any time, but should be kept globally unique to avoid confusion.
Corresponds to the JSON property displayName
2877 2878 2879 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2877 def display_name @display_name end |
#edition ⇒ String
Optional. The edition of the instance. See Edition for details.
Corresponds to the JSON property edition
2882 2883 2884 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2882 def edition @edition end |
#labels ⇒ Hash<String,String>
Labels are a flexible and lightweight mechanism for organizing cloud resources
into groups that reflect a customer's organizational needs and deployment
strategies. They can be used to filter resources and aggregate metrics. *
Label keys must be between 1 and 63 characters long and must conform to the
regular expression: \pLl\pLo0,62. * Label values must be between 0 and
63 characters long and must conform to the regular expression: [\pLl\pLo\
pN_-]0,63`. * No more than 64 labels can be associated with a given
resource. * Keys and values must both be under 128 bytes.
Corresponds to the JSON propertylabels`
2894 2895 2896 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2894 def labels @labels end |
#name ⇒ String
The unique name of the instance. Values are of the form projects/project/
instances/a-z+[a-z0-9].
Corresponds to the JSON property name
2900 2901 2902 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2900 def name @name end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzi
2905 2906 2907 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2905 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. Reserved for future use.
Corresponds to the JSON property satisfiesPzs
2911 2912 2913 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2911 def satisfies_pzs @satisfies_pzs end |
#state ⇒ String
Output only. The current state of the instance.
Corresponds to the JSON property state
2917 2918 2919 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2917 def state @state end |
#tags ⇒ Hash<String,String>
Optional. Input only. Immutable. Tag keys/values directly bound to this
resource. For example: - "123/environment": "production", - "123/costCenter": "
marketing" Tags and Labels (above) are both used to bind metadata to resources,
with different use-cases. See https://cloud.google.com/resource-manager/docs/
tags/tags-overview for an in-depth overview on the difference between tags and
labels.
Corresponds to the JSON property tags
2927 2928 2929 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2927 def @tags end |
#type ⇒ String
The type of the instance. Defaults to PRODUCTION.
Corresponds to the JSON property type
2932 2933 2934 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2932 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2939 2940 2941 2942 2943 2944 2945 2946 2947 2948 2949 2950 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2939 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @edition = args[:edition] if args.key?(:edition) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @state = args[:state] if args.key?(:state) @tags = args[:tags] if args.key?(:tags) @type = args[:type] if args.key?(:type) end |