Class: Google::Apis::BigtableadminV2::ListClustersResponse
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::ListClustersResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
Response message for BigtableInstanceAdmin.ListClusters.
Instance Attribute Summary collapse
-
#clusters ⇒ Array<Google::Apis::BigtableadminV2::Cluster>
The list of requested clusters.
-
#failed_locations ⇒ Array<String>
Locations from which Cluster information could not be retrieved, due to an outage or some other transient condition.
-
#next_page_token ⇒ String
DEPRECATED: This field is unused and ignored.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListClustersResponse
constructor
A new instance of ListClustersResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListClustersResponse
Returns a new instance of ListClustersResponse.
3108 3109 3110 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3108 def initialize(**args) update!(**args) end |
Instance Attribute Details
#clusters ⇒ Array<Google::Apis::BigtableadminV2::Cluster>
The list of requested clusters.
Corresponds to the JSON property clusters
3093 3094 3095 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3093 def clusters @clusters end |
#failed_locations ⇒ Array<String>
Locations from which Cluster information could not be retrieved, due to an
outage or some other transient condition. Clusters from these locations may be
missing from clusters, or may only have partial information returned. Values
are of the form projects//locations/
Corresponds to the JSON property failedLocations
3101 3102 3103 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3101 def failed_locations @failed_locations end |
#next_page_token ⇒ String
DEPRECATED: This field is unused and ignored.
Corresponds to the JSON property nextPageToken
3106 3107 3108 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3106 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3113 3114 3115 3116 3117 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3113 def update!(**args) @clusters = args[:clusters] if args.key?(:clusters) @failed_locations = args[:failed_locations] if args.key?(:failed_locations) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |