Class: Google::Apis::BigtableadminV2::ListClustersResponse
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::ListClustersResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
Response message for BigtableInstanceAdmin.ListClusters.
Instance Attribute Summary collapse
-
#clusters ⇒ Array<Google::Apis::BigtableadminV2::Cluster>
The list of requested clusters.
-
#failed_locations ⇒ Array<String>
Locations from which Cluster information could not be retrieved, due to an outage or some other transient condition.
-
#next_page_token ⇒ String
DEPRECATED: This field is unused and ignored.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListClustersResponse
constructor
A new instance of ListClustersResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListClustersResponse
Returns a new instance of ListClustersResponse.
3088 3089 3090 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3088 def initialize(**args) update!(**args) end |
Instance Attribute Details
#clusters ⇒ Array<Google::Apis::BigtableadminV2::Cluster>
The list of requested clusters.
Corresponds to the JSON property clusters
3073 3074 3075 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3073 def clusters @clusters end |
#failed_locations ⇒ Array<String>
Locations from which Cluster information could not be retrieved, due to an
outage or some other transient condition. Clusters from these locations may be
missing from clusters, or may only have partial information returned. Values
are of the form projects//locations/
Corresponds to the JSON property failedLocations
3081 3082 3083 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3081 def failed_locations @failed_locations end |
#next_page_token ⇒ String
DEPRECATED: This field is unused and ignored.
Corresponds to the JSON property nextPageToken
3086 3087 3088 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3086 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3093 3094 3095 3096 3097 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3093 def update!(**args) @clusters = args[:clusters] if args.key?(:clusters) @failed_locations = args[:failed_locations] if args.key?(:failed_locations) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |