Class: Google::Apis::BigtableadminV2::ListHotTabletsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

Response message for BigtableInstanceAdmin.ListHotTablets.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListHotTabletsResponse

Returns a new instance of ListHotTabletsResponse.



2979
2980
2981
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2979

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hot_tabletsArray<Google::Apis::BigtableadminV2::HotTablet>

List of hot tablets in the tables of the requested cluster that fall within the requested time range. Hot tablets are ordered by node cpu usage percent. If there are multiple hot tablets that correspond to the same tablet within a 15-minute interval, only the hot tablet with the highest node cpu usage will be included in the response. Corresponds to the JSON property hotTablets



2971
2972
2973
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2971

def hot_tablets
  @hot_tablets
end

#next_page_tokenString

Set if not all hot tablets could be returned in a single response. Pass this value to page_token in another request to get the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2977
2978
2979
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2977

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2984
2985
2986
2987
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2984

def update!(**args)
  @hot_tablets = args[:hot_tablets] if args.key?(:hot_tablets)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end