Class: Google::Apis::BigtableadminV2::ListHotTabletsResponse
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::ListHotTabletsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
Response message for BigtableInstanceAdmin.ListHotTablets.
Instance Attribute Summary collapse
-
#hot_tablets ⇒ Array<Google::Apis::BigtableadminV2::HotTablet>
List of hot tablets in the tables of the requested cluster that fall within the requested time range.
-
#next_page_token ⇒ String
Set if not all hot tablets could be returned in a single response.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListHotTabletsResponse
constructor
A new instance of ListHotTabletsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListHotTabletsResponse
Returns a new instance of ListHotTabletsResponse.
2965 2966 2967 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2965 def initialize(**args) update!(**args) end |
Instance Attribute Details
#hot_tablets ⇒ Array<Google::Apis::BigtableadminV2::HotTablet>
List of hot tablets in the tables of the requested cluster that fall within
the requested time range. Hot tablets are ordered by node cpu usage percent.
If there are multiple hot tablets that correspond to the same tablet within a
15-minute interval, only the hot tablet with the highest node cpu usage will
be included in the response.
Corresponds to the JSON property hotTablets
2957 2958 2959 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2957 def hot_tablets @hot_tablets end |
#next_page_token ⇒ String
Set if not all hot tablets could be returned in a single response. Pass this
value to page_token in another request to get the next page of results.
Corresponds to the JSON property nextPageToken
2963 2964 2965 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2963 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2970 2971 2972 2973 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 2970 def update!(**args) @hot_tablets = args[:hot_tablets] if args.key?(:hot_tablets) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |