Class: Google::Apis::BigtableadminV2::ListInstancesResponse
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::ListInstancesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
Response message for BigtableInstanceAdmin.ListInstances.
Instance Attribute Summary collapse
-
#failed_locations ⇒ Array<String>
Locations from which Instance information could not be retrieved, due to an outage or some other transient condition.
-
#instances ⇒ Array<Google::Apis::BigtableadminV2::Instance>
The list of requested instances.
-
#next_page_token ⇒ String
DEPRECATED: This field is unused and ignored.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListInstancesResponse
constructor
A new instance of ListInstancesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListInstancesResponse
Returns a new instance of ListInstancesResponse.
3153 3154 3155 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3153 def initialize(**args) update!(**args) end |
Instance Attribute Details
#failed_locations ⇒ Array<String>
Locations from which Instance information could not be retrieved, due to an
outage or some other transient condition. Instances whose Clusters are all in
one of the failed locations may be missing from instances, and Instances
with at least one Cluster in a failed location may only have partial
information returned. Values are of the form projects//locations/
Corresponds to the JSON property failedLocations
3141 3142 3143 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3141 def failed_locations @failed_locations end |
#instances ⇒ Array<Google::Apis::BigtableadminV2::Instance>
The list of requested instances.
Corresponds to the JSON property instances
3146 3147 3148 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3146 def instances @instances end |
#next_page_token ⇒ String
DEPRECATED: This field is unused and ignored.
Corresponds to the JSON property nextPageToken
3151 3152 3153 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3151 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3158 3159 3160 3161 3162 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3158 def update!(**args) @failed_locations = args[:failed_locations] if args.key?(:failed_locations) @instances = args[:instances] if args.key?(:instances) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |