Class: Google::Apis::BigtableadminV2::ListMemoryLayersResponse
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::ListMemoryLayersResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
Response message for BigtableInstanceAdmin.ListMemoryLayers.
Instance Attribute Summary collapse
-
#failed_locations ⇒ Array<String>
Locations from which MemoryLayer information could not be retrieved, due to an outage or some other transient condition.
-
#memory_layers ⇒ Array<Google::Apis::BigtableadminV2::MemoryLayer>
The list of requested memory layers.
-
#next_page_token ⇒ String
A token, which can be sent as
page_tokento retrieve the next page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListMemoryLayersResponse
constructor
A new instance of ListMemoryLayersResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListMemoryLayersResponse
Returns a new instance of ListMemoryLayersResponse.
3258 3259 3260 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3258 def initialize(**args) update!(**args) end |
Instance Attribute Details
#failed_locations ⇒ Array<String>
Locations from which MemoryLayer information could not be retrieved, due to an
outage or some other transient condition. MemoryLayers from these locations
may be missing from memory_layers, or may only have partial information
returned. Values are of the form projects//locations/
Corresponds to the JSON property failedLocations
3245 3246 3247 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3245 def failed_locations @failed_locations end |
#memory_layers ⇒ Array<Google::Apis::BigtableadminV2::MemoryLayer>
The list of requested memory layers.
Corresponds to the JSON property memoryLayers
3250 3251 3252 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3250 def memory_layers @memory_layers end |
#next_page_token ⇒ String
A token, which can be sent as page_token to retrieve the next page. If this
field is omitted, there are no subsequent pages.
Corresponds to the JSON property nextPageToken
3256 3257 3258 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3256 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3263 3264 3265 3266 3267 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3263 def update!(**args) @failed_locations = args[:failed_locations] if args.key?(:failed_locations) @memory_layers = args[:memory_layers] if args.key?(:memory_layers) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |