Class: Google::Apis::BigtableadminV2::LogicalView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

A SQL logical view object that can be referenced in SQL queries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LogicalView

Returns a new instance of LogicalView.



3431
3432
3433
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3431

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deletion_protectionBoolean Also known as: deletion_protection?

Optional. Set to true to make the LogicalView protected against deletion. Corresponds to the JSON property deletionProtection

Returns:

  • (Boolean)


3410
3411
3412
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3410

def deletion_protection
  @deletion_protection
end

#etagString

Optional. The etag for this logical view. This may be sent on update requests to ensure that the client has an up-to-date value before proceeding. The server returns an ABORTED error on a mismatched etag. Corresponds to the JSON property etag

Returns:

  • (String)


3418
3419
3420
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3418

def etag
  @etag
end

#nameString

Identifier. The unique name of the logical view. Format: projects/project/ instances/instance/logicalViews/logical_view` Corresponds to the JSON propertyname`

Returns:

  • (String)


3424
3425
3426
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3424

def name
  @name
end

#queryString

Required. The logical view's select query. Corresponds to the JSON property query

Returns:

  • (String)


3429
3430
3431
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3429

def query
  @query
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3436
3437
3438
3439
3440
3441
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3436

def update!(**args)
  @deletion_protection = args[:deletion_protection] if args.key?(:deletion_protection)
  @etag = args[:etag] if args.key?(:etag)
  @name = args[:name] if args.key?(:name)
  @query = args[:query] if args.key?(:query)
end