Class: Google::Apis::BigtableadminV2::LogicalView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

A SQL logical view object that can be referenced in SQL queries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LogicalView

Returns a new instance of LogicalView.



3249
3250
3251
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3249

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deletion_protectionBoolean Also known as: deletion_protection?

Optional. Set to true to make the LogicalView protected against deletion. Corresponds to the JSON property deletionProtection

Returns:

  • (Boolean)


3228
3229
3230
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3228

def deletion_protection
  @deletion_protection
end

#etagString

Optional. The etag for this logical view. This may be sent on update requests to ensure that the client has an up-to-date value before proceeding. The server returns an ABORTED error on a mismatched etag. Corresponds to the JSON property etag

Returns:

  • (String)


3236
3237
3238
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3236

def etag
  @etag
end

#nameString

Identifier. The unique name of the logical view. Format: projects/project/ instances/instance/logicalViews/logical_view` Corresponds to the JSON propertyname`

Returns:

  • (String)


3242
3243
3244
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3242

def name
  @name
end

#queryString

Required. The logical view's select query. Corresponds to the JSON property query

Returns:

  • (String)


3247
3248
3249
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3247

def query
  @query
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3254
3255
3256
3257
3258
3259
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3254

def update!(**args)
  @deletion_protection = args[:deletion_protection] if args.key?(:deletion_protection)
  @etag = args[:etag] if args.key?(:etag)
  @name = args[:name] if args.key?(:name)
  @query = args[:query] if args.key?(:query)
end