Class: Google::Apis::BigtableadminV2::MaterializedView

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

A materialized view object that can be referenced in SQL queries.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MaterializedView

Returns a new instance of MaterializedView.



3485
3486
3487
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3485

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_statesHash<String,Google::Apis::BigtableadminV2::GoogleBigtableAdminV2MaterializedViewClusterState>

Output only. Map from cluster ID to per-cluster materialized view state. If it could not be determined whether or not the materialized view has data in a particular cluster (for example, if its zone is unavailable), then there will be an entry for the cluster with STATE_NOT_KNOWN state. Views: REPLICATION_VIEW, FULL. Corresponds to the JSON property clusterStates



3455
3456
3457
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3455

def cluster_states
  @cluster_states
end

#deletion_protectionBoolean Also known as: deletion_protection?

Set to true to make the MaterializedView protected against deletion. Views: SCHEMA_VIEW, REPLICATION_VIEW, FULL. Corresponds to the JSON property deletionProtection

Returns:

  • (Boolean)


3461
3462
3463
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3461

def deletion_protection
  @deletion_protection
end

#etagString

Optional. The etag for this materialized view. This may be sent on update requests to ensure that the client has an up-to-date value before proceeding. The server returns an ABORTED error on a mismatched etag. Views: SCHEMA_VIEW, REPLICATION_VIEW, FULL. Corresponds to the JSON property etag

Returns:

  • (String)


3470
3471
3472
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3470

def etag
  @etag
end

#nameString

Identifier. The unique name of the materialized view. Format: projects/ project/instances/instance/materializedViews/materialized_view`Views: SCHEMA_VIEW,REPLICATION_VIEW,FULL. Corresponds to the JSON propertyname`

Returns:

  • (String)


3477
3478
3479
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3477

def name
  @name
end

#queryString

Required. Immutable. The materialized view's select query. Views: SCHEMA_VIEW , FULL. Corresponds to the JSON property query

Returns:

  • (String)


3483
3484
3485
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3483

def query
  @query
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3490
3491
3492
3493
3494
3495
3496
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3490

def update!(**args)
  @cluster_states = args[:cluster_states] if args.key?(:cluster_states)
  @deletion_protection = args[:deletion_protection] if args.key?(:deletion_protection)
  @etag = args[:etag] if args.key?(:etag)
  @name = args[:name] if args.key?(:name)
  @query = args[:query] if args.key?(:query)
end