Class: Google::Apis::BigtableadminV2::MaterializedView
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::MaterializedView
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
A materialized view object that can be referenced in SQL queries.
Instance Attribute Summary collapse
-
#cluster_states ⇒ Hash<String,Google::Apis::BigtableadminV2::GoogleBigtableAdminV2MaterializedViewClusterState>
Output only.
-
#deletion_protection ⇒ Boolean
(also: #deletion_protection?)
Set to true to make the MaterializedView protected against deletion.
-
#etag ⇒ String
Optional.
-
#name ⇒ String
Identifier.
-
#query ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MaterializedView
constructor
A new instance of MaterializedView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MaterializedView
Returns a new instance of MaterializedView.
3303 3304 3305 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3303 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_states ⇒ Hash<String,Google::Apis::BigtableadminV2::GoogleBigtableAdminV2MaterializedViewClusterState>
Output only. Map from cluster ID to per-cluster materialized view state. If it
could not be determined whether or not the materialized view has data in a
particular cluster (for example, if its zone is unavailable), then there will
be an entry for the cluster with STATE_NOT_KNOWN state. Views:
REPLICATION_VIEW, FULL.
Corresponds to the JSON property clusterStates
3273 3274 3275 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3273 def cluster_states @cluster_states end |
#deletion_protection ⇒ Boolean Also known as: deletion_protection?
Set to true to make the MaterializedView protected against deletion. Views:
SCHEMA_VIEW, REPLICATION_VIEW, FULL.
Corresponds to the JSON property deletionProtection
3279 3280 3281 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3279 def deletion_protection @deletion_protection end |
#etag ⇒ String
Optional. The etag for this materialized view. This may be sent on update
requests to ensure that the client has an up-to-date value before proceeding.
The server returns an ABORTED error on a mismatched etag. Views: SCHEMA_VIEW,
REPLICATION_VIEW, FULL.
Corresponds to the JSON property etag
3288 3289 3290 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3288 def etag @etag end |
#name ⇒ String
Identifier. The unique name of the materialized view. Format: projects/
project/instances/instance/materializedViews/materialized_view`Views:
SCHEMA_VIEW,REPLICATION_VIEW,FULL.
Corresponds to the JSON propertyname`
3295 3296 3297 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3295 def name @name end |
#query ⇒ String
Required. Immutable. The materialized view's select query. Views: SCHEMA_VIEW
, FULL.
Corresponds to the JSON property query
3301 3302 3303 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3301 def query @query end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3308 3309 3310 3311 3312 3313 3314 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3308 def update!(**args) @cluster_states = args[:cluster_states] if args.key?(:cluster_states) @deletion_protection = args[:deletion_protection] if args.key?(:deletion_protection) @etag = args[:etag] if args.key?(:etag) @name = args[:name] if args.key?(:name) @query = args[:query] if args.key?(:query) end |