Class: Google::Apis::BigtableadminV2::MemoryConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

If set, eligible single-row requests (currently limited to ReadRows) using this app profile will be routed to the memory layer. All eligible writes populate the memory layer. MemoryConfig can only be set if the AppProfile uses single cluster routing and the configured cluster has a memory layer enabled.

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MemoryConfig

Returns a new instance of MemoryConfig.



3506
3507
3508
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3506

def initialize(**args)
   update!(**args)
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3511
3512
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3511

def update!(**args)
end