Class: Google::Apis::BigtableadminV2::Modification

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

A create, update, or delete of a particular column family.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Modification

Returns a new instance of Modification.



3589
3590
3591
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3589

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#createGoogle::Apis::BigtableadminV2::ColumnFamily

A set of columns within a table which share a common configuration. Corresponds to the JSON property create



3563
3564
3565
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3563

def create
  @create
end

#dropBoolean Also known as: drop?

Drop (delete) the column family with the given ID, or fail if no such family exists. Corresponds to the JSON property drop

Returns:

  • (Boolean)


3569
3570
3571
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3569

def drop
  @drop
end

#idString

The ID of the column family to be modified. Corresponds to the JSON property id

Returns:

  • (String)


3575
3576
3577
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3575

def id
  @id
end

#updateGoogle::Apis::BigtableadminV2::ColumnFamily

A set of columns within a table which share a common configuration. Corresponds to the JSON property update



3580
3581
3582
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3580

def update
  @update
end

#update_maskString

Optional. A mask specifying which fields (e.g. gc_rule) in the update mod should be updated, ignored for other modification types. If unset or empty, we treat it as updating gc_rule to be backward compatible. Corresponds to the JSON property updateMask

Returns:

  • (String)


3587
3588
3589
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3587

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3594
3595
3596
3597
3598
3599
3600
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3594

def update!(**args)
  @create = args[:create] if args.key?(:create)
  @drop = args[:drop] if args.key?(:drop)
  @id = args[:id] if args.key?(:id)
  @update = args[:update] if args.key?(:update)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end