Class: Google::Apis::BigtableadminV2::OperationProgress

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

Encapsulates progress related information for a Cloud Bigtable long running operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationProgress

Returns a new instance of OperationProgress.



3753
3754
3755
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3753

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_timeString

If set, the time at which this operation failed or was completed successfully. Corresponds to the JSON property endTime

Returns:

  • (String)


3741
3742
3743
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3741

def end_time
  @end_time
end

#progress_percentFixnum

Percent completion of the operation. Values are between 0 and 100 inclusive. Corresponds to the JSON property progressPercent

Returns:

  • (Fixnum)


3746
3747
3748
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3746

def progress_percent
  @progress_percent
end

#start_timeString

Time the request was received. Corresponds to the JSON property startTime

Returns:

  • (String)


3751
3752
3753
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3751

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3758
3759
3760
3761
3762
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3758

def update!(**args)
  @end_time = args[:end_time] if args.key?(:end_time)
  @progress_percent = args[:progress_percent] if args.key?(:progress_percent)
  @start_time = args[:start_time] if args.key?(:start_time)
end