Class: Google::Apis::BigtableadminV2::PartialUpdateInstanceRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

Request message for BigtableInstanceAdmin.PartialUpdateInstance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PartialUpdateInstanceRequest

Returns a new instance of PartialUpdateInstanceRequest.



3867
3868
3869
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3867

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instanceGoogle::Apis::BigtableadminV2::Instance

A collection of Bigtable Tables and the resources that serve them. All tables in an instance are served from all Clusters in the instance. Corresponds to the JSON property instance



3859
3860
3861
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3859

def instance
  @instance
end

#update_maskString

Required. The subset of Instance fields which should be replaced. Must be explicitly set. Corresponds to the JSON property updateMask

Returns:

  • (String)


3865
3866
3867
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3865

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3872
3873
3874
3875
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3872

def update!(**args)
  @instance = args[:instance] if args.key?(:instance)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end