Class: Google::Apis::BigtableadminV2::PartialUpdateInstanceRequest
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::PartialUpdateInstanceRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
Request message for BigtableInstanceAdmin.PartialUpdateInstance.
Instance Attribute Summary collapse
-
#instance ⇒ Google::Apis::BigtableadminV2::Instance
A collection of Bigtable Tables and the resources that serve them.
-
#update_mask ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PartialUpdateInstanceRequest
constructor
A new instance of PartialUpdateInstanceRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PartialUpdateInstanceRequest
Returns a new instance of PartialUpdateInstanceRequest.
3642 3643 3644 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3642 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instance ⇒ Google::Apis::BigtableadminV2::Instance
A collection of Bigtable Tables and the resources that serve them. All tables
in an instance are served from all Clusters in the instance.
Corresponds to the JSON property instance
3634 3635 3636 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3634 def instance @instance end |
#update_mask ⇒ String
Required. The subset of Instance fields which should be replaced. Must be
explicitly set.
Corresponds to the JSON property updateMask
3640 3641 3642 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3640 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3647 3648 3649 3650 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3647 def update!(**args) @instance = args[:instance] if args.key?(:instance) @update_mask = args[:update_mask] if args.key?(:update_mask) end |