Class: Google::Apis::BigtableadminV2::RestoreTableMetadata
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::RestoreTableMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
Metadata type for the long-running operation returned by RestoreTable.
Instance Attribute Summary collapse
-
#backup_info ⇒ Google::Apis::BigtableadminV2::BackupInfo
Information about a backup.
-
#name ⇒ String
Name of the table being created and restored to.
-
#optimize_table_operation_name ⇒ String
If exists, the name of the long-running operation that will be used to track the post-restore optimization process to optimize the performance of the restored table.
-
#progress ⇒ Google::Apis::BigtableadminV2::OperationProgress
Encapsulates progress related information for a Cloud Bigtable long running operation.
-
#source_type ⇒ String
The type of the restore source.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RestoreTableMetadata
constructor
A new instance of RestoreTableMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RestoreTableMetadata
Returns a new instance of RestoreTableMetadata.
4063 4064 4065 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4063 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_info ⇒ Google::Apis::BigtableadminV2::BackupInfo
Information about a backup.
Corresponds to the JSON property backupInfo
4033 4034 4035 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4033 def backup_info @backup_info end |
#name ⇒ String
Name of the table being created and restored to.
Corresponds to the JSON property name
4038 4039 4040 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4038 def name @name end |
#optimize_table_operation_name ⇒ String
If exists, the name of the long-running operation that will be used to track
the post-restore optimization process to optimize the performance of the
restored table. The metadata type of the long-running operation is
OptimizeRestoredTableMetadata. The response type is Empty. This long-running
operation may be automatically created by the system if applicable after the
RestoreTable long-running operation completes successfully. This operation may
not be created if the table is already optimized or the restore was not
successful.
Corresponds to the JSON property optimizeTableOperationName
4050 4051 4052 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4050 def optimize_table_operation_name @optimize_table_operation_name end |
#progress ⇒ Google::Apis::BigtableadminV2::OperationProgress
Encapsulates progress related information for a Cloud Bigtable long running
operation.
Corresponds to the JSON property progress
4056 4057 4058 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4056 def progress @progress end |
#source_type ⇒ String
The type of the restore source.
Corresponds to the JSON property sourceType
4061 4062 4063 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4061 def source_type @source_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4068 4069 4070 4071 4072 4073 4074 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4068 def update!(**args) @backup_info = args[:backup_info] if args.key?(:backup_info) @name = args[:name] if args.key?(:name) @optimize_table_operation_name = args[:optimize_table_operation_name] if args.key?(:optimize_table_operation_name) @progress = args[:progress] if args.key?(:progress) @source_type = args[:source_type] if args.key?(:source_type) end |