Class: Google::Apis::BigtableadminV2::RestoreTableMetadata
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::RestoreTableMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
Metadata type for the long-running operation returned by RestoreTable.
Instance Attribute Summary collapse
-
#backup_info ⇒ Google::Apis::BigtableadminV2::BackupInfo
Information about a backup.
-
#name ⇒ String
Name of the table being created and restored to.
-
#optimize_table_operation_name ⇒ String
If exists, the name of the long-running operation that will be used to track the post-restore optimization process to optimize the performance of the restored table.
-
#progress ⇒ Google::Apis::BigtableadminV2::OperationProgress
Encapsulates progress related information for a Cloud Bigtable long running operation.
-
#source_type ⇒ String
The type of the restore source.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RestoreTableMetadata
constructor
A new instance of RestoreTableMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RestoreTableMetadata
Returns a new instance of RestoreTableMetadata.
3824 3825 3826 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3824 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_info ⇒ Google::Apis::BigtableadminV2::BackupInfo
Information about a backup.
Corresponds to the JSON property backupInfo
3794 3795 3796 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3794 def backup_info @backup_info end |
#name ⇒ String
Name of the table being created and restored to.
Corresponds to the JSON property name
3799 3800 3801 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3799 def name @name end |
#optimize_table_operation_name ⇒ String
If exists, the name of the long-running operation that will be used to track
the post-restore optimization process to optimize the performance of the
restored table. The metadata type of the long-running operation is
OptimizeRestoredTableMetadata. The response type is Empty. This long-running
operation may be automatically created by the system if applicable after the
RestoreTable long-running operation completes successfully. This operation may
not be created if the table is already optimized or the restore was not
successful.
Corresponds to the JSON property optimizeTableOperationName
3811 3812 3813 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3811 def optimize_table_operation_name @optimize_table_operation_name end |
#progress ⇒ Google::Apis::BigtableadminV2::OperationProgress
Encapsulates progress related information for a Cloud Bigtable long running
operation.
Corresponds to the JSON property progress
3817 3818 3819 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3817 def progress @progress end |
#source_type ⇒ String
The type of the restore source.
Corresponds to the JSON property sourceType
3822 3823 3824 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3822 def source_type @source_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3829 3830 3831 3832 3833 3834 3835 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 3829 def update!(**args) @backup_info = args[:backup_info] if args.key?(:backup_info) @name = args[:name] if args.key?(:name) @optimize_table_operation_name = args[:optimize_table_operation_name] if args.key?(:optimize_table_operation_name) @progress = args[:progress] if args.key?(:progress) @source_type = args[:source_type] if args.key?(:source_type) end |