Class: Google::Apis::BigtableadminV2::RowAffinity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

If enabled, Bigtable will route the request based on the row key of the request, rather than randomly. Instead, each row key will be assigned to a cluster, and will stick to that cluster. If clusters are added or removed, then this may affect which row keys stick to which clusters. To avoid this, users can use a cluster group to specify which clusters are to be used. In this case, new clusters that are not a part of the cluster group will not be routed to, and routing will be unaffected by the new cluster. Moreover, clusters specified in the cluster group cannot be deleted unless removed from the cluster group.

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RowAffinity

Returns a new instance of RowAffinity.



4117
4118
4119
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4117

def initialize(**args)
   update!(**args)
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4122
4123
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4122

def update!(**args)
end