Class: Google::Apis::BigtableadminV2::StandardIsolation
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::StandardIsolation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
Standard options for isolating this app profile's traffic from other use cases.
Instance Attribute Summary collapse
-
#memory_config ⇒ Google::Apis::BigtableadminV2::MemoryConfig
If set, eligible single-row requests (currently limited to ReadRows) using this app profile will be routed to the memory layer.
-
#priority ⇒ String
The priority of requests sent using this app profile.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StandardIsolation
constructor
A new instance of StandardIsolation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StandardIsolation
Returns a new instance of StandardIsolation.
4308 4309 4310 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4308 def initialize(**args) update!(**args) end |
Instance Attribute Details
#memory_config ⇒ Google::Apis::BigtableadminV2::MemoryConfig
If set, eligible single-row requests (currently limited to ReadRows) using
this app profile will be routed to the memory layer. All eligible writes
populate the memory layer. MemoryConfig can only be set if the AppProfile uses
single cluster routing and the configured cluster has a memory layer enabled.
Corresponds to the JSON property memoryConfig
4301 4302 4303 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4301 def memory_config @memory_config end |
#priority ⇒ String
The priority of requests sent using this app profile.
Corresponds to the JSON property priority
4306 4307 4308 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4306 def priority @priority end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4313 4314 4315 4316 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4313 def update!(**args) @memory_config = args[:memory_config] if args.key?(:memory_config) @priority = args[:priority] if args.key?(:priority) end |