Class: Google::Apis::BigtableadminV2::StandardIsolation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

Standard options for isolating this app profile's traffic from other use cases.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StandardIsolation

Returns a new instance of StandardIsolation.



4281
4282
4283
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4281

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#memory_configGoogle::Apis::BigtableadminV2::MemoryConfig

If set, eligible single-row requests (currently limited to ReadRows) using this app profile will be routed to the memory layer. All eligible writes populate the memory layer. MemoryConfig can only be set if the AppProfile uses single cluster routing and the configured cluster has a memory layer enabled. Corresponds to the JSON property memoryConfig



4274
4275
4276
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4274

def memory_config
  @memory_config
end

#priorityString

The priority of requests sent using this app profile. Corresponds to the JSON property priority

Returns:

  • (String)


4279
4280
4281
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4279

def priority
  @priority
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4286
4287
4288
4289
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4286

def update!(**args)
  @memory_config = args[:memory_config] if args.key?(:memory_config)
  @priority = args[:priority] if args.key?(:priority)
end