Class: Google::Apis::BigtableadminV2::Table

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

A collection of user data indexed by row, column, and timestamp. Each table is served using the resources of its parent cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Table

Returns a new instance of Table.



4427
4428
4429
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4427

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#automated_backup_policyGoogle::Apis::BigtableadminV2::AutomatedBackupPolicy

Defines an automated backup policy for a table Corresponds to the JSON property automatedBackupPolicy



4353
4354
4355
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4353

def automated_backup_policy
  @automated_backup_policy
end

#change_stream_configGoogle::Apis::BigtableadminV2::ChangeStreamConfig

Change stream configuration. Corresponds to the JSON property changeStreamConfig



4358
4359
4360
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4358

def change_stream_config
  @change_stream_config
end

#cluster_statesHash<String,Google::Apis::BigtableadminV2::ClusterState>

Output only. Map from cluster ID to per-cluster table state. If it could not be determined whether or not the table has data in a particular cluster (for example, if its zone is unavailable), then there will be an entry for the cluster with UNKNOWN replication_status. Views: REPLICATION_VIEW, ENCRYPTION_VIEW, FULL Corresponds to the JSON property clusterStates



4367
4368
4369
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4367

def cluster_states
  @cluster_states
end

#column_familiesHash<String,Google::Apis::BigtableadminV2::ColumnFamily>

The column families configured for this table, mapped by column family ID. Views: SCHEMA_VIEW, STATS_VIEW, FULL Corresponds to the JSON property columnFamilies



4373
4374
4375
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4373

def column_families
  @column_families
end

#deletion_protectionBoolean Also known as: deletion_protection?

Set to true to make the table protected against data loss. i.e. deleting the following resources through Admin APIs are prohibited: * The table. * The column families in the table. * The instance containing the table. Note one can still delete the data stored in the table through Data APIs. Corresponds to the JSON property deletionProtection

Returns:

  • (Boolean)


4381
4382
4383
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4381

def deletion_protection
  @deletion_protection
end

#granularityString

Immutable. The granularity at which timestamps are stored in this table. Timestamps not matching the granularity will be rejected. If unspecified at creation time, the value will be set to MILLIS. Views: SCHEMA_VIEW, FULL. Corresponds to the JSON property granularity

Returns:

  • (String)


4389
4390
4391
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4389

def granularity
  @granularity
end

#nameString

The unique name of the table. Values are of the form projects/project/ instances/instance/tables/_a-zA-Z0-9*. Views: NAME_ONLY, SCHEMA_VIEW, REPLICATION_VIEW, STATS_VIEW, FULL Corresponds to the JSON property name

Returns:

  • (String)


4396
4397
4398
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4396

def name
  @name
end

#restore_infoGoogle::Apis::BigtableadminV2::RestoreInfo

Information about a table restore. Corresponds to the JSON property restoreInfo



4401
4402
4403
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4401

def restore_info
  @restore_info
end

#row_key_schemaGoogle::Apis::BigtableadminV2::GoogleBigtableAdminV2TypeStruct

A structured data value, consisting of fields which map to dynamically typed values. Values of type Struct are stored in Value.array_value where entries are in the same order and number as field_types. Corresponds to the JSON property rowKeySchema



4408
4409
4410
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4408

def row_key_schema
  @row_key_schema
end

#statsGoogle::Apis::BigtableadminV2::TableStats

Approximate statistics related to a table. These statistics are calculated infrequently, while simultaneously, data in the table can change rapidly. Thus the values reported here (e.g. row count) are very likely out-of date, even the instant they are received in this API. Thus, only treat these values as approximate. IMPORTANT: Everything below is approximate, unless otherwise specified. Corresponds to the JSON property stats



4418
4419
4420
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4418

def stats
  @stats
end

#tiered_storage_configGoogle::Apis::BigtableadminV2::TieredStorageConfig

Config for tiered storage. A valid config must have a valid TieredStorageRule. Otherwise the whole TieredStorageConfig must be unset. By default all data is stored in the SSD tier (only SSD instances can configure tiered storage). Corresponds to the JSON property tieredStorageConfig



4425
4426
4427
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4425

def tiered_storage_config
  @tiered_storage_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4432
4433
4434
4435
4436
4437
4438
4439
4440
4441
4442
4443
4444
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4432

def update!(**args)
  @automated_backup_policy = args[:automated_backup_policy] if args.key?(:automated_backup_policy)
  @change_stream_config = args[:change_stream_config] if args.key?(:change_stream_config)
  @cluster_states = args[:cluster_states] if args.key?(:cluster_states)
  @column_families = args[:column_families] if args.key?(:column_families)
  @deletion_protection = args[:deletion_protection] if args.key?(:deletion_protection)
  @granularity = args[:granularity] if args.key?(:granularity)
  @name = args[:name] if args.key?(:name)
  @restore_info = args[:restore_info] if args.key?(:restore_info)
  @row_key_schema = args[:row_key_schema] if args.key?(:row_key_schema)
  @stats = args[:stats] if args.key?(:stats)
  @tiered_storage_config = args[:tiered_storage_config] if args.key?(:tiered_storage_config)
end