Class: Google::Apis::BigtableadminV2::Table
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::Table
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
A collection of user data indexed by row, column, and timestamp. Each table is served using the resources of its parent cluster.
Instance Attribute Summary collapse
-
#automated_backup_policy ⇒ Google::Apis::BigtableadminV2::AutomatedBackupPolicy
Defines an automated backup policy for a table Corresponds to the JSON property
automatedBackupPolicy. -
#change_stream_config ⇒ Google::Apis::BigtableadminV2::ChangeStreamConfig
Change stream configuration.
-
#cluster_states ⇒ Hash<String,Google::Apis::BigtableadminV2::ClusterState>
Output only.
-
#column_families ⇒ Hash<String,Google::Apis::BigtableadminV2::ColumnFamily>
The column families configured for this table, mapped by column family ID.
-
#deletion_protection ⇒ Boolean
(also: #deletion_protection?)
Set to true to make the table protected against data loss.
-
#granularity ⇒ String
Immutable.
-
#name ⇒ String
The unique name of the table.
-
#restore_info ⇒ Google::Apis::BigtableadminV2::RestoreInfo
Information about a table restore.
-
#row_key_schema ⇒ Google::Apis::BigtableadminV2::GoogleBigtableAdminV2TypeStruct
A structured data value, consisting of fields which map to dynamically typed values.
-
#stats ⇒ Google::Apis::BigtableadminV2::TableStats
Approximate statistics related to a table.
-
#tiered_storage_config ⇒ Google::Apis::BigtableadminV2::TieredStorageConfig
Config for tiered storage.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Table
constructor
A new instance of Table.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Table
Returns a new instance of Table.
4194 4195 4196 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4194 def initialize(**args) update!(**args) end |
Instance Attribute Details
#automated_backup_policy ⇒ Google::Apis::BigtableadminV2::AutomatedBackupPolicy
Defines an automated backup policy for a table
Corresponds to the JSON property automatedBackupPolicy
4119 4120 4121 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4119 def automated_backup_policy @automated_backup_policy end |
#change_stream_config ⇒ Google::Apis::BigtableadminV2::ChangeStreamConfig
Change stream configuration.
Corresponds to the JSON property changeStreamConfig
4124 4125 4126 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4124 def change_stream_config @change_stream_config end |
#cluster_states ⇒ Hash<String,Google::Apis::BigtableadminV2::ClusterState>
Output only. Map from cluster ID to per-cluster table state. If it could not
be determined whether or not the table has data in a particular cluster (for
example, if its zone is unavailable), then there will be an entry for the
cluster with UNKNOWN replication_status. Views: REPLICATION_VIEW,
ENCRYPTION_VIEW, FULL
Corresponds to the JSON property clusterStates
4133 4134 4135 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4133 def cluster_states @cluster_states end |
#column_families ⇒ Hash<String,Google::Apis::BigtableadminV2::ColumnFamily>
The column families configured for this table, mapped by column family ID.
Views: SCHEMA_VIEW, STATS_VIEW, FULL
Corresponds to the JSON property columnFamilies
4139 4140 4141 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4139 def column_families @column_families end |
#deletion_protection ⇒ Boolean Also known as: deletion_protection?
Set to true to make the table protected against data loss. i.e. deleting the
following resources through Admin APIs are prohibited: * The table. * The
column families in the table. * The instance containing the table. Note one
can still delete the data stored in the table through Data APIs.
Corresponds to the JSON property deletionProtection
4147 4148 4149 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4147 def deletion_protection @deletion_protection end |
#granularity ⇒ String
Immutable. The granularity (i.e. MILLIS) at which timestamps are stored in
this table. Timestamps not matching the granularity will be rejected. If
unspecified at creation time, the value will be set to MILLIS. Views:
SCHEMA_VIEW, FULL.
Corresponds to the JSON property granularity
4156 4157 4158 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4156 def granularity @granularity end |
#name ⇒ String
The unique name of the table. Values are of the form projects/project/
instances/instance/tables/_a-zA-Z0-9*. Views: NAME_ONLY, SCHEMA_VIEW,
REPLICATION_VIEW, STATS_VIEW, FULL
Corresponds to the JSON property name
4163 4164 4165 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4163 def name @name end |
#restore_info ⇒ Google::Apis::BigtableadminV2::RestoreInfo
Information about a table restore.
Corresponds to the JSON property restoreInfo
4168 4169 4170 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4168 def restore_info @restore_info end |
#row_key_schema ⇒ Google::Apis::BigtableadminV2::GoogleBigtableAdminV2TypeStruct
A structured data value, consisting of fields which map to dynamically typed
values. Values of type Struct are stored in Value.array_value where
entries are in the same order and number as field_types.
Corresponds to the JSON property rowKeySchema
4175 4176 4177 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4175 def row_key_schema @row_key_schema end |
#stats ⇒ Google::Apis::BigtableadminV2::TableStats
Approximate statistics related to a table. These statistics are calculated
infrequently, while simultaneously, data in the table can change rapidly. Thus
the values reported here (e.g. row count) are very likely out-of date, even
the instant they are received in this API. Thus, only treat these values as
approximate. IMPORTANT: Everything below is approximate, unless otherwise
specified.
Corresponds to the JSON property stats
4185 4186 4187 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4185 def stats @stats end |
#tiered_storage_config ⇒ Google::Apis::BigtableadminV2::TieredStorageConfig
Config for tiered storage. A valid config must have a valid TieredStorageRule.
Otherwise the whole TieredStorageConfig must be unset. By default all data is
stored in the SSD tier (only SSD instances can configure tiered storage).
Corresponds to the JSON property tieredStorageConfig
4192 4193 4194 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4192 def tiered_storage_config @tiered_storage_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4199 4200 4201 4202 4203 4204 4205 4206 4207 4208 4209 4210 4211 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4199 def update!(**args) @automated_backup_policy = args[:automated_backup_policy] if args.key?(:automated_backup_policy) @change_stream_config = args[:change_stream_config] if args.key?(:change_stream_config) @cluster_states = args[:cluster_states] if args.key?(:cluster_states) @column_families = args[:column_families] if args.key?(:column_families) @deletion_protection = args[:deletion_protection] if args.key?(:deletion_protection) @granularity = args[:granularity] if args.key?(:granularity) @name = args[:name] if args.key?(:name) @restore_info = args[:restore_info] if args.key?(:restore_info) @row_key_schema = args[:row_key_schema] if args.key?(:row_key_schema) @stats = args[:stats] if args.key?(:stats) @tiered_storage_config = args[:tiered_storage_config] if args.key?(:tiered_storage_config) end |