Class: Google::Apis::BigtableadminV2::TieredStorageConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

Config for tiered storage. A valid config must have a valid TieredStorageRule. Otherwise the whole TieredStorageConfig must be unset. By default all data is stored in the SSD tier (only SSD instances can configure tiered storage).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TieredStorageConfig

Returns a new instance of TieredStorageConfig.



4582
4583
4584
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4582

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#infrequent_accessGoogle::Apis::BigtableadminV2::TieredStorageRule

Rule to specify what data is stored in a storage tier. Corresponds to the JSON property infrequentAccess



4580
4581
4582
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4580

def infrequent_access
  @infrequent_access
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4587
4588
4589
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4587

def update!(**args)
  @infrequent_access = args[:infrequent_access] if args.key?(:infrequent_access)
end