Class: Google::Apis::BigtableadminV2::TieredStorageConfig
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::TieredStorageConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
Config for tiered storage. A valid config must have a valid TieredStorageRule. Otherwise the whole TieredStorageConfig must be unset. By default all data is stored in the SSD tier (only SSD instances can configure tiered storage).
Instance Attribute Summary collapse
-
#infrequent_access ⇒ Google::Apis::BigtableadminV2::TieredStorageRule
Rule to specify what data is stored in a storage tier.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TieredStorageConfig
constructor
A new instance of TieredStorageConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TieredStorageConfig
Returns a new instance of TieredStorageConfig.
4335 4336 4337 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4335 def initialize(**args) update!(**args) end |
Instance Attribute Details
#infrequent_access ⇒ Google::Apis::BigtableadminV2::TieredStorageRule
Rule to specify what data is stored in a storage tier.
Corresponds to the JSON property infrequentAccess
4333 4334 4335 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4333 def infrequent_access @infrequent_access end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4340 4341 4342 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4340 def update!(**args) @infrequent_access = args[:infrequent_access] if args.key?(:infrequent_access) end |