Class: Google::Apis::BigtableadminV2::UndeleteTableMetadata
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::UndeleteTableMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
Metadata type for the operation returned by google.bigtable.admin.v2. BigtableTableAdmin.UndeleteTable.
Instance Attribute Summary collapse
-
#end_time ⇒ String
If set, the time at which this operation finished or was cancelled.
-
#finish_time ⇒ String
The time at which the operation failed or was completed successfully.
-
#name ⇒ String
The name of the table being restored.
-
#request_time ⇒ String
The time at which the original request was received.
-
#start_time ⇒ String
The time at which this operation started.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UndeleteTableMetadata
constructor
A new instance of UndeleteTableMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UndeleteTableMetadata
Returns a new instance of UndeleteTableMetadata.
4519 4520 4521 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4519 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
If set, the time at which this operation finished or was cancelled. DEPRECATED:
Use finish_time instead.
Corresponds to the JSON property endTime
4497 4498 4499 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4497 def end_time @end_time end |
#finish_time ⇒ String
The time at which the operation failed or was completed successfully.
Corresponds to the JSON property finishTime
4502 4503 4504 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4502 def finish_time @finish_time end |
#name ⇒ String
The name of the table being restored.
Corresponds to the JSON property name
4507 4508 4509 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4507 def name @name end |
#request_time ⇒ String
The time at which the original request was received.
Corresponds to the JSON property requestTime
4512 4513 4514 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4512 def request_time @request_time end |
#start_time ⇒ String
The time at which this operation started. DEPRECATED: Use request_time instead.
Corresponds to the JSON property startTime
4517 4518 4519 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4517 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4524 4525 4526 4527 4528 4529 4530 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4524 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @finish_time = args[:finish_time] if args.key?(:finish_time) @name = args[:name] if args.key?(:name) @request_time = args[:request_time] if args.key?(:request_time) @start_time = args[:start_time] if args.key?(:start_time) end |