Class: Google::Apis::BigtableadminV2::UpdateLogicalViewRequest
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::UpdateLogicalViewRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
Request message for BigtableInstanceAdmin.UpdateLogicalView.
Instance Attribute Summary collapse
-
#logical_view ⇒ Google::Apis::BigtableadminV2::LogicalView
A SQL logical view object that can be referenced in SQL queries.
-
#update_mask ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpdateLogicalViewRequest
constructor
A new instance of UpdateLogicalViewRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpdateLogicalViewRequest
Returns a new instance of UpdateLogicalViewRequest.
4766 4767 4768 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4766 def initialize(**args) update!(**args) end |
Instance Attribute Details
#logical_view ⇒ Google::Apis::BigtableadminV2::LogicalView
A SQL logical view object that can be referenced in SQL queries.
Corresponds to the JSON property logicalView
4759 4760 4761 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4759 def logical_view @logical_view end |
#update_mask ⇒ String
Optional. The list of fields to update.
Corresponds to the JSON property updateMask
4764 4765 4766 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4764 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4771 4772 4773 4774 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4771 def update!(**args) @logical_view = args[:logical_view] if args.key?(:logical_view) @update_mask = args[:update_mask] if args.key?(:update_mask) end |