Class: Google::Apis::BigtableadminV2::UpdateSchemaBundleMetadata
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::UpdateSchemaBundleMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
The metadata for the Operation returned by UpdateSchemaBundle.
Instance Attribute Summary collapse
-
#finish_time ⇒ String
The time at which the operation failed or was completed successfully.
-
#name ⇒ String
The unique name identifying this schema bundle.
-
#request_time ⇒ String
The time at which the original request was received.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpdateSchemaBundleMetadata
constructor
A new instance of UpdateSchemaBundleMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpdateSchemaBundleMetadata
Returns a new instance of UpdateSchemaBundleMetadata.
4819 4820 4821 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4819 def initialize(**args) update!(**args) end |
Instance Attribute Details
#finish_time ⇒ String
The time at which the operation failed or was completed successfully.
Corresponds to the JSON property finishTime
4805 4806 4807 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4805 def finish_time @finish_time end |
#name ⇒ String
The unique name identifying this schema bundle. Values are of the form
projects/project/instances/instance/tables/table/schemaBundles/
schema_bundle`
Corresponds to the JSON propertyname`
4812 4813 4814 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4812 def name @name end |
#request_time ⇒ String
The time at which the original request was received.
Corresponds to the JSON property requestTime
4817 4818 4819 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4817 def request_time @request_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4824 4825 4826 4827 4828 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4824 def update!(**args) @finish_time = args[:finish_time] if args.key?(:finish_time) @name = args[:name] if args.key?(:name) @request_time = args[:request_time] if args.key?(:request_time) end |