Class: Google::Apis::BigtableadminV2::UpdateSchemaBundleMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

The metadata for the Operation returned by UpdateSchemaBundle.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpdateSchemaBundleMetadata

Returns a new instance of UpdateSchemaBundleMetadata.



4798
4799
4800
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4798

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#finish_timeString

The time at which the operation failed or was completed successfully. Corresponds to the JSON property finishTime

Returns:

  • (String)


4784
4785
4786
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4784

def finish_time
  @finish_time
end

#nameString

The unique name identifying this schema bundle. Values are of the form projects/project/instances/instance/tables/table/schemaBundles/ schema_bundle` Corresponds to the JSON propertyname`

Returns:

  • (String)


4791
4792
4793
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4791

def name
  @name
end

#request_timeString

The time at which the original request was received. Corresponds to the JSON property requestTime

Returns:

  • (String)


4796
4797
4798
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4796

def request_time
  @request_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4803
4804
4805
4806
4807
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4803

def update!(**args)
  @finish_time = args[:finish_time] if args.key?(:finish_time)
  @name = args[:name] if args.key?(:name)
  @request_time = args[:request_time] if args.key?(:request_time)
end