Class: Google::Apis::BigtableadminV2::UpdateTableMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

Metadata type for the operation returned by UpdateTable.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpdateTableMetadata

Returns a new instance of UpdateTableMetadata.



5164
5165
5166
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 5164

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_timeString

If set, the time at which this operation finished or was canceled. DEPRECATED: Use finish_time instead. Corresponds to the JSON property endTime

Returns:

  • (String)


5142
5143
5144
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 5142

def end_time
  @end_time
end

#finish_timeString

The time at which the operation failed or was completed successfully. Corresponds to the JSON property finishTime

Returns:

  • (String)


5147
5148
5149
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 5147

def finish_time
  @finish_time
end

#nameString

The name of the table being updated. Corresponds to the JSON property name

Returns:

  • (String)


5152
5153
5154
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 5152

def name
  @name
end

#request_timeString

The time at which the original request was received. Corresponds to the JSON property requestTime

Returns:

  • (String)


5157
5158
5159
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 5157

def request_time
  @request_time
end

#start_timeString

The time at which this operation started. DEPRECATED: Use request_time instead. Corresponds to the JSON property startTime

Returns:

  • (String)


5162
5163
5164
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 5162

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5169
5170
5171
5172
5173
5174
5175
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 5169

def update!(**args)
  @end_time = args[:end_time] if args.key?(:end_time)
  @finish_time = args[:finish_time] if args.key?(:finish_time)
  @name = args[:name] if args.key?(:name)
  @request_time = args[:request_time] if args.key?(:request_time)
  @start_time = args[:start_time] if args.key?(:start_time)
end