Class: Google::Apis::BigtableadminV2::UpdateTableMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

Metadata type for the operation returned by UpdateTable.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpdateTableMetadata

Returns a new instance of UpdateTableMetadata.



5157
5158
5159
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 5157

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_timeString

If set, the time at which this operation finished or was canceled. DEPRECATED: Use finish_time instead. Corresponds to the JSON property endTime

Returns:

  • (String)


5135
5136
5137
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 5135

def end_time
  @end_time
end

#finish_timeString

The time at which the operation failed or was completed successfully. Corresponds to the JSON property finishTime

Returns:

  • (String)


5140
5141
5142
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 5140

def finish_time
  @finish_time
end

#nameString

The name of the table being updated. Corresponds to the JSON property name

Returns:

  • (String)


5145
5146
5147
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 5145

def name
  @name
end

#request_timeString

The time at which the original request was received. Corresponds to the JSON property requestTime

Returns:

  • (String)


5150
5151
5152
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 5150

def request_time
  @request_time
end

#start_timeString

The time at which this operation started. DEPRECATED: Use request_time instead. Corresponds to the JSON property startTime

Returns:

  • (String)


5155
5156
5157
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 5155

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5162
5163
5164
5165
5166
5167
5168
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 5162

def update!(**args)
  @end_time = args[:end_time] if args.key?(:end_time)
  @finish_time = args[:finish_time] if args.key?(:finish_time)
  @name = args[:name] if args.key?(:name)
  @request_time = args[:request_time] if args.key?(:request_time)
  @start_time = args[:start_time] if args.key?(:start_time)
end