Class: Google::Apis::BigtableadminV2::UpdateTableMetadata
- Inherits:
-
Object
- Object
- Google::Apis::BigtableadminV2::UpdateTableMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb
Overview
Metadata type for the operation returned by UpdateTable.
Instance Attribute Summary collapse
-
#end_time ⇒ String
If set, the time at which this operation finished or was canceled.
-
#finish_time ⇒ String
The time at which the operation failed or was completed successfully.
-
#name ⇒ String
The name of the table being updated.
-
#request_time ⇒ String
The time at which the original request was received.
-
#start_time ⇒ String
The time at which this operation started.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpdateTableMetadata
constructor
A new instance of UpdateTableMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpdateTableMetadata
Returns a new instance of UpdateTableMetadata.
5157 5158 5159 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 5157 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
If set, the time at which this operation finished or was canceled. DEPRECATED:
Use finish_time instead.
Corresponds to the JSON property endTime
5135 5136 5137 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 5135 def end_time @end_time end |
#finish_time ⇒ String
The time at which the operation failed or was completed successfully.
Corresponds to the JSON property finishTime
5140 5141 5142 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 5140 def finish_time @finish_time end |
#name ⇒ String
The name of the table being updated.
Corresponds to the JSON property name
5145 5146 5147 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 5145 def name @name end |
#request_time ⇒ String
The time at which the original request was received.
Corresponds to the JSON property requestTime
5150 5151 5152 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 5150 def request_time @request_time end |
#start_time ⇒ String
The time at which this operation started. DEPRECATED: Use request_time instead.
Corresponds to the JSON property startTime
5155 5156 5157 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 5155 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5162 5163 5164 5165 5166 5167 5168 |
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 5162 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @finish_time = args[:finish_time] if args.key?(:finish_time) @name = args[:name] if args.key?(:name) @request_time = args[:request_time] if args.key?(:request_time) @start_time = args[:start_time] if args.key?(:start_time) end |