Class: Google::Apis::BigtableadminV2::UpdateTableMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/bigtableadmin_v2/classes.rb,
lib/google/apis/bigtableadmin_v2/representations.rb,
lib/google/apis/bigtableadmin_v2/representations.rb

Overview

Metadata type for the operation returned by UpdateTable.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpdateTableMetadata

Returns a new instance of UpdateTableMetadata.



4840
4841
4842
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4840

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_timeString

If set, the time at which this operation finished or was canceled. DEPRECATED: Use finish_time instead. Corresponds to the JSON property endTime

Returns:

  • (String)


4818
4819
4820
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4818

def end_time
  @end_time
end

#finish_timeString

The time at which the operation failed or was completed successfully. Corresponds to the JSON property finishTime

Returns:

  • (String)


4823
4824
4825
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4823

def finish_time
  @finish_time
end

#nameString

The name of the table being updated. Corresponds to the JSON property name

Returns:

  • (String)


4828
4829
4830
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4828

def name
  @name
end

#request_timeString

The time at which the original request was received. Corresponds to the JSON property requestTime

Returns:

  • (String)


4833
4834
4835
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4833

def request_time
  @request_time
end

#start_timeString

The time at which this operation started. DEPRECATED: Use request_time instead. Corresponds to the JSON property startTime

Returns:

  • (String)


4838
4839
4840
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4838

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4845
4846
4847
4848
4849
4850
4851
# File 'lib/google/apis/bigtableadmin_v2/classes.rb', line 4845

def update!(**args)
  @end_time = args[:end_time] if args.key?(:end_time)
  @finish_time = args[:finish_time] if args.key?(:finish_time)
  @name = args[:name] if args.key?(:name)
  @request_time = args[:request_time] if args.key?(:request_time)
  @start_time = args[:start_time] if args.key?(:start_time)
end